@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Match Grun and the Claws Mail team
+ * Copyright (C) 2001-2009 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,13 +30,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkhbbox.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 #include "gtkutils.h"
 #include "stock_pixmap.h"
@@ -56,7 +50,7 @@ typedef struct {
 	gchar **folder_path;
 	gboolean matched;
 	gint index;
-	GtkCTreeNode *node;
+	GtkCMCTreeNode *node;
 } FolderPathMatch;
 
 static struct _AddressBookFolderSel_dlg {
@@ -68,10 +62,8 @@ static struct _AddressBookFolderSel_dlg {
 	FolderInfo *fiSelected;
 } addressbook_foldersel_dlg;
 
-static GdkPixmap *folderXpm;
-static GdkBitmap *folderXpmMask;
-static GdkPixmap *bookXpm;
-static GdkBitmap *bookXpmMask;
+static GdkPixbuf *folderXpm;
+static GdkPixbuf *bookXpm;
 
 static gboolean addressbook_foldersel_cancelled;
 
@@ -117,13 +109,13 @@ static void addressbook_foldersel_cancel( GtkWidget *widget, gboolean *cancelled
 	gtk_main_quit();
 }
 
-static void addressbook_foldersel_folder_select( GtkCTree *ctree, gint row, gint column,
-					GdkEvent *event, gpointer data )
+static void addressbook_foldersel_folder_select( GtkCMCTree *ctree, GtkCMCTreeNode *node,
+				      gint column, gpointer data )
 {
-	addressbook_foldersel_dlg.fiSelected = gtk_clist_get_row_data( GTK_CLIST(ctree), row );
+	addressbook_foldersel_dlg.fiSelected = gtk_cmctree_node_get_row_data( ctree, node );
 }
 
-static gboolean addressbook_foldersel_tree_button( GtkCTree *ctree, GdkEventButton *event, gpointer data )
+static gboolean addressbook_foldersel_tree_button( GtkCMCTree *ctree, GdkEventButton *event, gpointer data )
 {
 	if ( ! event )
 		return FALSE;
@@ -141,7 +133,7 @@ static gboolean addressbook_foldersel_tree_button( GtkCTree *ctree, GdkEventButt
 static void addressbook_foldersel_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.addressbook_folderselwin_width = allocation->width;
 	prefs_common.addressbook_folderselwin_height = allocation->height;
@@ -158,6 +150,7 @@ static void addressbook_foldersel_create( void )
 	GtkWidget *ok_btn;
 	GtkWidget *cancel_btn;
 	static GdkGeometry geometry;
+	gchar *titles[1];
 
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "addressbook_foldersel" );
 	gtk_container_set_border_width( GTK_CONTAINER(window), 0 );
@@ -186,15 +179,24 @@ static void addressbook_foldersel_create( void )
 				        GTK_POLICY_AUTOMATIC );
 	gtk_box_pack_start( GTK_BOX(vlbox), tree_win, TRUE, TRUE, 0 );
 
-	tree_folder = gtk_ctree_new( 1, 0 );
+	titles[0] = _( "Address Book") ;
+
+	tree_folder = gtk_sctree_new_with_titles( 1, 0, titles );
 	gtk_container_add( GTK_CONTAINER(tree_win), tree_folder );
-	gtk_clist_column_titles_show( GTK_CLIST(tree_folder) );
-	gtk_clist_set_column_title( GTK_CLIST(tree_folder), 0, _( "Address Book" ) );
-	gtk_ctree_set_line_style( GTK_CTREE(tree_folder), GTK_CTREE_LINES_DOTTED );
-	gtk_clist_set_selection_mode( GTK_CLIST(tree_folder), GTK_SELECTION_BROWSE );
-	gtk_ctree_set_expander_style( GTK_CTREE(tree_folder), GTK_CTREE_EXPANDER_SQUARE );
-	gtk_ctree_set_indent( GTK_CTREE(tree_folder), CTREE_INDENT );
-	gtk_clist_set_auto_sort( GTK_CLIST(tree_folder), TRUE );
+	gtk_cmclist_column_titles_show( GTK_CMCLIST(tree_folder) );
+	if (prefs_common.enable_dotted_lines) {
+		gtk_cmctree_set_line_style(GTK_CMCTREE(tree_folder), GTK_CMCTREE_LINES_DOTTED);
+		gtk_cmctree_set_expander_style(GTK_CMCTREE(tree_folder),
+				     GTK_CMCTREE_EXPANDER_SQUARE);
+	} else {
+		gtk_cmctree_set_line_style(GTK_CMCTREE(tree_folder), GTK_CMCTREE_LINES_NONE);
+		gtk_cmctree_set_expander_style(GTK_CMCTREE(tree_folder),
+				     GTK_CMCTREE_EXPANDER_TRIANGLE);
+	}
+	gtk_sctree_set_stripes(GTK_SCTREE(tree_folder), prefs_common.use_stripes_everywhere);
+	gtk_cmclist_set_selection_mode( GTK_CMCLIST(tree_folder), GTK_SELECTION_BROWSE );
+	gtk_cmctree_set_indent( GTK_CMCTREE(tree_folder), CTREE_INDENT );
+	gtk_cmclist_set_auto_sort( GTK_CMCLIST(tree_folder), TRUE );
 
 	/* Button panel */
 	gtkut_stock_button_set_create( &hbbox, &cancel_btn, GTK_STOCK_CANCEL,
@@ -208,7 +210,7 @@ static void addressbook_foldersel_create( void )
 			 G_CALLBACK(addressbook_foldersel_ok), NULL );
 	g_signal_connect( G_OBJECT(cancel_btn), "clicked",
 			 G_CALLBACK(addressbook_foldersel_cancel), NULL );
-	g_signal_connect( G_OBJECT(tree_folder), "select_row",
+	g_signal_connect( G_OBJECT(tree_folder), "tree_select_row",
 			 G_CALLBACK(addressbook_foldersel_folder_select), NULL );
 	g_signal_connect( G_OBJECT(tree_folder), "button_press_event",
 			 G_CALLBACK(addressbook_foldersel_tree_button), NULL );
@@ -232,20 +234,20 @@ static void addressbook_foldersel_create( void )
 
 	gtk_widget_show_all( window );
 
-	stock_pixmap_gdk( window, STOCK_PIXMAP_BOOK, &bookXpm, &bookXpmMask );
-	stock_pixmap_gdk( window, STOCK_PIXMAP_DIR_OPEN,
-			  &folderXpm, &folderXpmMask );
+	stock_pixbuf_gdk( window, STOCK_PIXMAP_BOOK, &bookXpm);
+	stock_pixbuf_gdk( window, STOCK_PIXMAP_DIR_OPEN,
+			  &folderXpm);
 }
 
-static void addressbook_foldersel_load_folder( GtkCTreeNode *parentNode, ItemFolder *parentFolder,
+static void addressbook_foldersel_load_folder( GtkCMCTreeNode *parentNode, ItemFolder *parentFolder,
 					FolderInfo *fiParent, FolderPathMatch *match )
 {
-	GtkCTree *tree = GTK_CTREE( addressbook_foldersel_dlg.tree_folder );
+	GtkCMCTree *tree = GTK_CMCTREE( addressbook_foldersel_dlg.tree_folder );
 	GList *list;
 	ItemFolder *folder;
 	gchar *fName;
 	gchar **name;
-	GtkCTreeNode *node;
+	GtkCMCTreeNode *node;
 	FolderInfo *fi;
 	FolderPathMatch *nextmatch = NULL;
 
@@ -255,8 +257,8 @@ static void addressbook_foldersel_load_folder( GtkCTreeNode *parentNode, ItemFol
 		fName = g_strdup( ADDRITEM_NAME(folder) );
 
 		name = &fName;
-		node = gtk_ctree_insert_node( tree, parentNode, NULL, name, FOLDER_SPACING,
-				folderXpm, folderXpmMask, folderXpm, folderXpmMask,
+		node = gtk_cmctree_insert_node( tree, parentNode, NULL, name, FOLDER_SPACING,
+				folderXpm, folderXpm,
 				FALSE, TRUE );
 
 		/* match folder name, match pointer will be set to NULL if next recursive call
@@ -285,8 +287,8 @@ static void addressbook_foldersel_load_folder( GtkCTreeNode *parentNode, ItemFol
 		g_free( fName );
 
 		fi = addressbook_foldersel_create_folderinfo( fiParent->book, folder );
-		gtk_ctree_node_set_row_data_full( tree, node, fi,
-				( GtkDestroyNotify ) addressbook_foldersel_free_folderinfo );
+		gtk_cmctree_node_set_row_data_full( tree, node, fi,
+				( GDestroyNotify ) addressbook_foldersel_free_folderinfo );
 		addressbook_foldersel_load_folder( node, folder, fi, nextmatch );
 		list = g_list_next( list );
 	}
@@ -302,11 +304,11 @@ static void addressbook_foldersel_load_data( AddressIndex *addrIndex,
 	ItemFolder *rootFolder;
 	AddressBookFile *abf;
 	FolderInfo *fi;
-	GtkCTree *tree = GTK_CTREE( addressbook_foldersel_dlg.tree_folder );
-	GtkCTreeNode *node;
+	GtkCMCTree *tree = GTK_CMCTREE( addressbook_foldersel_dlg.tree_folder );
+	GtkCMCTreeNode *node;
 	FolderPathMatch *nextmatch;
 
-	gtk_clist_clear( GTK_CLIST( tree ) );
+	gtk_cmclist_clear( GTK_CMCLIST( tree ) );
 	list = addrindex_get_interface_list( addrIndex );
 	while ( list ) {
 		AddressInterface *interface = list->data;
@@ -324,9 +326,9 @@ static void addressbook_foldersel_load_data( AddressIndex *addrIndex,
 				/* Add node for address book */
 				abf = ds->rawDataSource;
 				name = &dsName;
-				node = gtk_ctree_insert_node( tree, NULL, NULL,
+				node = gtk_cmctree_insert_node( tree, NULL, NULL,
 						name, FOLDER_SPACING, bookXpm,
-						bookXpmMask, bookXpm, bookXpmMask,
+						bookXpm,
 						FALSE, TRUE );
 				g_free( dsName );
 
@@ -354,8 +356,8 @@ static void addressbook_foldersel_load_data( AddressIndex *addrIndex,
 				}
 
 				fi = addressbook_foldersel_create_folderinfo( abf, NULL );
-				gtk_ctree_node_set_row_data_full( tree, node, fi,
-						( GtkDestroyNotify ) addressbook_foldersel_free_folderinfo );
+				gtk_cmctree_node_set_row_data_full( tree, node, fi,
+						( GDestroyNotify ) addressbook_foldersel_free_folderinfo );
 
 				rootFolder = addrindex_ds_get_root_folder( ds );
 				addressbook_foldersel_load_folder( node, rootFolder, fi, nextmatch );
@@ -388,8 +390,9 @@ gboolean addressbook_foldersel_selection( AddressIndex *addrIndex,
        corresponds to what we received */
 
 	if ( path != NULL ) {
-		if ( strcasecmp(path, _("Any")) == 0 || *path == '\0' )
-			/* consider "Any" and "" as valid addressbook root */
+		if ( g_utf8_collate(path, _("Any")) == 0 || strcasecmp(path, "Any") ==0 || *path == '\0' )
+			/* consider "Any" (both translated or untranslated forms) and ""
+			   as valid addressbook roots */
 			folder_path_match.matched = TRUE;
 		else
 			folder_path_match.folder_path = g_strsplit( path, "/", 256 );
@@ -403,10 +406,10 @@ gboolean addressbook_foldersel_selection( AddressIndex *addrIndex,
 	g_strfreev( folder_path_match.folder_path );
 
 	if ( folder_path_match.node != NULL)
-		gtk_ctree_select( GTK_CTREE( addressbook_foldersel_dlg.tree_folder ),
-							GTK_CTREE_NODE( folder_path_match.node ) );
+		gtk_cmctree_select( GTK_CMCTREE( addressbook_foldersel_dlg.tree_folder ),
+							GTK_CMCTREE_NODE( folder_path_match.node ) );
 	else
-		gtk_clist_select_row( GTK_CLIST( addressbook_foldersel_dlg.tree_folder ), 0, 0 );
+		gtk_cmclist_select_row( GTK_CMCLIST( addressbook_foldersel_dlg.tree_folder ), 0, 0 );
 	gtk_widget_show(addressbook_foldersel_dlg.window);
 
 	gtk_main();
@@ -424,7 +427,7 @@ gboolean addressbook_foldersel_selection( AddressIndex *addrIndex,
 		}
 	}
 
-	gtk_clist_clear( GTK_CLIST( addressbook_foldersel_dlg.tree_folder ) );
+	gtk_cmclist_clear( GTK_CMCLIST( addressbook_foldersel_dlg.tree_folder ) );
 
 	return retVal;
 }
