@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,8 +39,6 @@
 #include "tags.h"
 #include "log.h"
 
-#define PREFSBUFSIZE		1024
-
 GSList * pre_global_processing = NULL;
 GSList * post_global_processing = NULL;
 GSList * filtering_rules = NULL;
@@ -89,7 +87,7 @@ FilteringAction * filteringaction_new(int type, int account_id,
 
 void filteringaction_free(FilteringAction * action)
 {
-	g_return_if_fail(action);
+	cm_return_if_fail(action);
 	g_free(action->header);
 	g_free(action->destination);
 	g_free(action);
@@ -170,12 +168,13 @@ void filteringprop_free(FilteringProp * prop)
 {
         GSList * tmp;
 
-	g_return_if_fail(prop);
+	cm_return_if_fail(prop);
 	matcherlist_free(prop->matchers);
         
         for (tmp = prop->action_list ; tmp != NULL ; tmp = tmp->next) {
                 filteringaction_free(tmp->data);
         }
+	g_slist_free(prop->action_list);
 	g_free(prop->name);
 	g_free(prop);
 }
@@ -468,7 +467,7 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 			gint errors = 0;
 
 			if (!addressbook_peek_folder_exists(action->destination, &book, &folder)) {
-				g_warning("addressbook folder not found '%s'\n", action->destination);
+				g_warning("addressbook folder not found '%s'\n", action->destination?action->destination:"(null)");
 				return FALSE;
 			}
 			if (!book) {
@@ -489,7 +488,7 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 				gchar *path = NULL;
 
 				if (action->destination == NULL ||
-						strcasecmp(action->destination, _("Any")) == 0 ||
+						strcasecmp(action->destination, "Any") == 0 ||
 						*(action->destination) == '\0')
 					path = NULL;
 				else
@@ -518,7 +517,7 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 				g_slist_free(address_list);
 				end_address_completion();
 			} else {
-				g_warning("header '%s' not set or empty\n", action->header);
+				g_warning("header '%s' not set or empty\n", action->header?action->header:"(null)");
 			}
 			return (errors == 0);
 		}
@@ -532,8 +531,8 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 gboolean filteringaction_apply_action_list(GSList *action_list, MsgInfo *info)
 {
 	GSList *p;
-	g_return_val_if_fail(action_list, FALSE);
-	g_return_val_if_fail(info, FALSE);
+	cm_return_val_if_fail(action_list, FALSE);
+	cm_return_val_if_fail(info, FALSE);
 	for (p = action_list; p && p->data; p = g_slist_next(p)) {
 		FilteringAction *a = (FilteringAction *) p->data;
 		if (filteringaction_apply(a, info)) {
@@ -587,7 +586,7 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 						log_status_ok(LOG_DEBUG_FILTERING,
 								_("rule is account-based [id=%d, name='%s'], "
 								"matching the account currently used to retrieve messages\n"),
-								ac_prefs->account_id, ac_prefs->account_name);
+								ac_prefs->account_id, ac_prefs?ac_prefs->account_name:_("NON_EXISTENT"));
 					}
 				}
 			}
@@ -604,8 +603,8 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based [id=%d, name='%s'], "
 								"not matching the account currently used to retrieve messages [id=%d, name='%s']\n"),
-								filtering->account_id, account->account_name,
-								ac_prefs->account_id, ac_prefs->account_name);
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"),
+								ac_prefs->account_id, ac_prefs?ac_prefs->account_name:_("NON_EXISTENT"));
 					}
 				}
 			}
@@ -629,7 +628,7 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 						log_status_ok(LOG_DEBUG_FILTERING,
 								_("rule is account-based [id=%d, name='%s'], "
 								"but all rules are applied on user request\n"),
-								filtering->account_id, account->account_name);
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
 					}
 				}
 			}
@@ -647,7 +646,7 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based [id=%d, name='%s'], "
 								"skipped on user request\n"),
-								filtering->account_id, account->account_name);
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
 					} else {
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based, "
@@ -674,8 +673,8 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based [id=%d, name='%s'], "
 								"not matching current account [id=%d, name='%s']\n"),
-								filtering->account_id, account->account_name,
-								cur_account->account_id, cur_account->account_name);
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"),
+								cur_account->account_id, cur_account?cur_account->account_name:_("NON_EXISTENT"));
 					} else {
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based, "
@@ -692,8 +691,8 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 							log_status_ok(LOG_DEBUG_FILTERING,
 									_("rule is account-based [id=%d, name='%s'], "
 									"current account [id=%d, name='%s']\n"),
-									account->account_id, account->account_name,
-									cur_account->account_id, cur_account->account_name);
+									account->account_id, account?account->account_name:_("NON_EXISTENT"),
+									cur_account->account_id, cur_account?cur_account->account_name:_("NON_EXISTENT"));
 						}
 					}
 				}
@@ -777,7 +776,7 @@ static gboolean filter_msginfo(GSList * filtering_list, MsgInfo * info, PrefsAcc
 	gboolean final;
 	gboolean apply_next;
 	
-	g_return_val_if_fail(info != NULL, TRUE);
+	cm_return_val_if_fail(info != NULL, TRUE);
 	
 	for (l = filtering_list, final = FALSE, apply_next = FALSE; l != NULL; l = g_slist_next(l)) {
 		FilteringProp * filtering = (FilteringProp *) l->data;
@@ -794,6 +793,7 @@ static gboolean filter_msginfo(GSList * filtering_list, MsgInfo * info, PrefsAcc
 						_("processing rule <unnamed> [ %s ]\n"),
 						buf);
 				}
+				g_free(buf);
 			}
 
 			if (filtering_match_condition(filtering, info, ac_prefs)) {
@@ -850,7 +850,7 @@ gboolean filter_message_by_msginfo(GSList *flist, MsgInfo *info, PrefsAccount* a
 
 	if (prefs_common.enable_filtering_debug) {
 		gchar *tmp = _("undetermined");
-
+#ifndef G_OS_WIN32
 		switch (context) {
 		case FILTERING_INCORPORATION:
 			tmp = _("incorporation");
@@ -876,6 +876,9 @@ gboolean filter_message_by_msginfo(GSList *flist, MsgInfo *info, PrefsAccount* a
 			debug_filtering_session = FALSE;
 			break;
 		}
+#else
+		debug_filtering_session = FALSE;
+#endif
 		if (debug_filtering_session) {
 			gchar *file = procmsg_get_message_file_path(info);
 			gchar *spc = g_strnfill(LOG_TIME_LEN + 1, ' ');
@@ -1013,6 +1016,9 @@ gchar * filteringprop_to_string(FilteringProp * prop)
 	gchar *action_list_str;
 	gchar *filtering_str;
 
+	if (prop == NULL)
+		return NULL;
+
         action_list_str = filteringaction_list_to_string(prop->action_list);
 
 	if (action_list_str == NULL)
@@ -1046,8 +1052,8 @@ static gboolean prefs_filtering_free_func(GNode *node, gpointer data)
 {
 	FolderItem *item = node->data;
 
-	g_return_val_if_fail(item, FALSE);
-	g_return_val_if_fail(item->prefs, FALSE);
+	cm_return_val_if_fail(item, FALSE);
+	cm_return_val_if_fail(item->prefs, FALSE);
 
 	prefs_filtering_free(item->prefs->processing);
 	item->prefs->processing = NULL;
@@ -1077,8 +1083,8 @@ void prefs_filtering_clear(void)
 
 void prefs_filtering_clear_folder(Folder *folder)
 {
-	g_return_if_fail(folder);
-	g_return_if_fail(folder->node);
+	cm_return_if_fail(folder);
+	cm_return_if_fail(folder->node);
 
 	g_node_traverse(folder->node, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 			prefs_filtering_free_func, NULL);
