@@ -12,7 +12,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -21,9 +21,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA. 
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
  
 #ifdef HAVE_CONFIG_H
@@ -39,8 +37,7 @@
 #include "image_viewer.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtktextview.h>
+#include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print-pango.h>
 
 #ifdef ENABLE_PROFILE
@@ -480,7 +477,7 @@ gtk_source_print_job_finalize (GObject *object)
 	GtkSourcePrintJob *job;
 	GtkSourcePrintJobPrivate *priv;
 	
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (object));
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (object));
 	
 	job = GTK_SOURCE_PRINT_JOB (object);
 	priv = job->priv;
@@ -676,7 +673,7 @@ gtk_source_print_job_set_property (GObject      *object,
 static void 
 gtk_source_print_job_begin_page (GtkSourcePrintJob *job)
 {
-	g_return_if_fail (job->priv->printing);
+	cm_return_if_fail (job->priv->printing);
 	
 	if (job->priv->print_header && job->priv->header_height > 0)
 	{
@@ -839,8 +836,8 @@ update_page_size_and_margins (GtkSourcePrintJob *job)
 				  job->priv->header_height - job->priv->footer_height);
 
 	/* FIXME: put some saner values than 5cm - Gustavo */
-	g_return_val_if_fail (job->priv->text_width > CM(5.0), FALSE);
-	g_return_val_if_fail (job->priv->text_height > CM(5.0), FALSE);
+	cm_return_val_if_fail (job->priv->text_width > CM(5.0), FALSE);
+	cm_return_val_if_fail (job->priv->text_height > CM(5.0), FALSE);
 
 	return TRUE;
 }
@@ -985,7 +982,7 @@ text_style_new (GtkSourcePrintJob *job, GtkTextTag *tag)
 	TextStyle *style;
 	gboolean bg_set, fg_set;
 	
-	g_return_val_if_fail (tag != NULL && GTK_IS_TEXT_TAG (tag), NULL);
+	cm_return_val_if_fail (tag != NULL && GTK_IS_TEXT_TAG (tag), NULL);
 
 	style = g_new0 (TextStyle, 1);
 
@@ -1210,8 +1207,8 @@ get_text_to_print (GtkSourcePrintJob *job,
 	GtkTextIter _start, _end;
 	gboolean retval;
 	
-	g_return_val_if_fail (start != NULL && end != NULL, FALSE);
-	g_return_val_if_fail (job->priv->buffer != NULL, FALSE);
+	cm_return_val_if_fail (start != NULL && end != NULL, FALSE);
+	cm_return_val_if_fail (job->priv->buffer != NULL, FALSE);
 
 	_start = *start;
 	_end = *end;
@@ -1803,7 +1800,7 @@ gtk_source_print_job_new (GnomePrintConfig  *config)
 {
 	GtkSourcePrintJob *job;
 
-	g_return_val_if_fail (config == NULL || GNOME_IS_PRINT_CONFIG (config), NULL);
+	cm_return_val_if_fail (config == NULL || GNOME_IS_PRINT_CONFIG (config), NULL);
 
 	job = GTK_SOURCE_PRINT_JOB (g_object_new (GTK_TYPE_SOURCE_PRINT_JOB, NULL));
 	if (config != NULL)
@@ -1827,8 +1824,8 @@ gtk_source_print_job_new_with_buffer (GnomePrintConfig  *config,
 {
 	GtkSourcePrintJob *job;
 
-	g_return_val_if_fail (config == NULL || GNOME_IS_PRINT_CONFIG (config), NULL);
-	g_return_val_if_fail (buffer == NULL || GTK_IS_TEXT_BUFFER (buffer), NULL);
+	cm_return_val_if_fail (config == NULL || GNOME_IS_PRINT_CONFIG (config), NULL);
+	cm_return_val_if_fail (buffer == NULL || GTK_IS_TEXT_BUFFER (buffer), NULL);
 
 	job = gtk_source_print_job_new (config);
 	if (buffer != NULL)
@@ -1852,9 +1849,9 @@ void
 gtk_source_print_job_set_config (GtkSourcePrintJob *job,
 				 GnomePrintConfig  *config)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (GNOME_IS_PRINT_CONFIG (config));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (GNOME_IS_PRINT_CONFIG (config));
+	cm_return_if_fail (!job->priv->printing);
 	
 	if (config == job->priv->config)
 		return;
@@ -1881,7 +1878,7 @@ gtk_source_print_job_set_config (GtkSourcePrintJob *job,
 GnomePrintConfig * 
 gtk_source_print_job_get_config (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	ensure_print_config (job);
 	
@@ -1901,9 +1898,9 @@ void
 gtk_source_print_job_set_buffer (GtkSourcePrintJob *job,
 				 GtkTextBuffer   *buffer)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (buffer == job->priv->buffer)
 		return;
@@ -1930,7 +1927,7 @@ gtk_source_print_job_set_buffer (GtkSourcePrintJob *job,
 GtkTextBuffer *
 gtk_source_print_job_get_buffer (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	return job->priv->buffer;
 }
@@ -1951,8 +1948,8 @@ void
 gtk_source_print_job_set_tabs_width (GtkSourcePrintJob *job,
 				     guint              tabs_width)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (tabs_width == job->priv->tabs_width)
 		return;
@@ -1974,7 +1971,7 @@ gtk_source_print_job_set_tabs_width (GtkSourcePrintJob *job,
 guint 
 gtk_source_print_job_get_tabs_width (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
 
 	return job->priv->tabs_width;
 }
@@ -1991,8 +1988,8 @@ void
 gtk_source_print_job_set_wrap_mode (GtkSourcePrintJob *job,
 				    GtkWrapMode        wrap)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (wrap == job->priv->wrap_mode)
 		return;
@@ -2014,7 +2011,7 @@ gtk_source_print_job_set_wrap_mode (GtkSourcePrintJob *job,
 GtkWrapMode 
 gtk_source_print_job_get_wrap_mode (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), GTK_WRAP_NONE);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), GTK_WRAP_NONE);
 
 	return job->priv->wrap_mode;
 }
@@ -2031,8 +2028,8 @@ void
 gtk_source_print_job_set_highlight (GtkSourcePrintJob *job,
 				    gboolean           highlight)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	highlight = (highlight != FALSE);
 	
@@ -2057,7 +2054,7 @@ gtk_source_print_job_set_highlight (GtkSourcePrintJob *job,
 gboolean 
 gtk_source_print_job_get_highlight (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
 
 	return job->priv->highlight;
 }
@@ -2073,9 +2070,9 @@ void
 gtk_source_print_job_set_font_desc (GtkSourcePrintJob    *job,
 				    PangoFontDescription *desc)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (desc != NULL);
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (desc != NULL);
+	cm_return_if_fail (!job->priv->printing);
 
 	desc = pango_font_description_copy (desc);
 	if (job->priv->font != NULL)
@@ -2107,9 +2104,9 @@ gtk_source_print_job_set_font (GtkSourcePrintJob *job,
 {
 	PangoFontDescription *desc;
 	
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (font_name != NULL);
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (font_name != NULL);
+	cm_return_if_fail (!job->priv->printing);
 
 	desc = font_description_from_gnome_font_name (font_name);
 	if (desc)
@@ -2134,7 +2131,7 @@ gtk_source_print_job_set_font (GtkSourcePrintJob *job,
 PangoFontDescription *
 gtk_source_print_job_get_font_desc (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	ensure_print_config (job);
 	
@@ -2161,7 +2158,7 @@ gtk_source_print_job_get_font_desc (GtkSourcePrintJob *job)
 gchar *
 gtk_source_print_job_get_font (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	ensure_print_config (job);
 	
@@ -2185,8 +2182,8 @@ gtk_source_print_job_setup_from_view (GtkSourcePrintJob *job,
 	GtkTextBuffer *buffer = NULL;
 	PangoContext *pango_context;
 	
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	buffer = gtk_text_view_get_buffer (view);
 	
@@ -2215,8 +2212,8 @@ void
 gtk_source_print_job_set_numbers_font_desc (GtkSourcePrintJob    *job,
 					    PangoFontDescription *desc)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 	
 	if (desc)
 		desc = pango_font_description_copy (desc);
@@ -2249,8 +2246,8 @@ gtk_source_print_job_set_numbers_font (GtkSourcePrintJob *job,
 {
 	PangoFontDescription *desc;
 	
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (font_name != NULL)
 	{
@@ -2278,7 +2275,7 @@ gtk_source_print_job_set_numbers_font (GtkSourcePrintJob *job,
 PangoFontDescription *
 gtk_source_print_job_get_numbers_font_desc (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	return job->priv->numbers_font;
 }
@@ -2304,7 +2301,7 @@ gtk_source_print_job_get_numbers_font_desc (GtkSourcePrintJob *job)
 gchar *
 gtk_source_print_job_get_numbers_font (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	if (job->priv->numbers_font != NULL)
 		return font_description_to_gnome_font_name (job->priv->numbers_font);
@@ -2325,8 +2322,8 @@ void
 gtk_source_print_job_set_print_numbers (GtkSourcePrintJob *job,
 					guint              interval)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (interval == job->priv->print_numbers)
 		return;
@@ -2349,7 +2346,7 @@ gtk_source_print_job_set_print_numbers (GtkSourcePrintJob *job,
 guint 
 gtk_source_print_job_get_print_numbers (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
 
 	return job->priv->print_numbers;
 }
@@ -2382,8 +2379,8 @@ gtk_source_print_job_set_text_margins (GtkSourcePrintJob *job,
 				       gdouble            left,
 				       gdouble            right)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (top >= 0)
 		job->priv->margin_top = top;
@@ -2416,7 +2413,7 @@ gtk_source_print_job_get_text_margins (GtkSourcePrintJob *job,
 				       gdouble           *left,
 				       gdouble           *right)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
 
 	if (top != NULL)
 		*top = job->priv->margin_top;
@@ -2437,10 +2434,10 @@ gtk_source_print_job_prepare (GtkSourcePrintJob *job,
 {
 	PROFILE (GTimer *timer);
 	
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
-	g_return_val_if_fail (!job->priv->printing, FALSE);
-	g_return_val_if_fail (job->priv->buffer != NULL, FALSE);
-	g_return_val_if_fail (start != NULL && end != NULL, FALSE);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
+	cm_return_val_if_fail (!job->priv->printing, FALSE);
+	cm_return_val_if_fail (job->priv->buffer != NULL, FALSE);
+	cm_return_val_if_fail (start != NULL && end != NULL, FALSE);
 
 	/* make sure we have a sane configuration to start printing */
 	ensure_print_config (job);
@@ -2492,9 +2489,9 @@ gtk_source_print_job_print (GtkSourcePrintJob *job)
 {
 	GtkTextIter start, end;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
-	g_return_val_if_fail (!job->priv->printing, NULL);
-	g_return_val_if_fail (job->priv->buffer != NULL, NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (!job->priv->printing, NULL);
+	cm_return_val_if_fail (job->priv->buffer != NULL, NULL);
 
 	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (job->priv->buffer), &start, &end);
 
@@ -2519,11 +2516,11 @@ gtk_source_print_job_print_range (GtkSourcePrintJob *job,
 				  const GtkTextIter *start,
 				  const GtkTextIter *end)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
-	g_return_val_if_fail (!job->priv->printing, NULL);
-	g_return_val_if_fail (job->priv->buffer != NULL, NULL);
-	g_return_val_if_fail (start != NULL && end != NULL, NULL);
-	g_return_val_if_fail (gtk_text_iter_get_buffer (start) ==
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (!job->priv->printing, NULL);
+	cm_return_val_if_fail (job->priv->buffer != NULL, NULL);
+	cm_return_val_if_fail (start != NULL && end != NULL, NULL);
+	cm_return_val_if_fail (gtk_text_iter_get_buffer (start) ==
 			      GTK_TEXT_BUFFER (job->priv->buffer) &&
 			      gtk_text_iter_get_buffer (end) ==
 			      GTK_TEXT_BUFFER (job->priv->buffer), NULL);
@@ -2575,11 +2572,11 @@ gtk_source_print_job_print_range_async (GtkSourcePrintJob *job,
 {
 	GSource *idle_source;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
-	g_return_val_if_fail (!job->priv->printing, FALSE);
-	g_return_val_if_fail (job->priv->buffer != NULL, FALSE);
-	g_return_val_if_fail (start != NULL && end != NULL, FALSE);
-	g_return_val_if_fail (gtk_text_iter_get_buffer (start) ==
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
+	cm_return_val_if_fail (!job->priv->printing, FALSE);
+	cm_return_val_if_fail (job->priv->buffer != NULL, FALSE);
+	cm_return_val_if_fail (start != NULL && end != NULL, FALSE);
+	cm_return_val_if_fail (gtk_text_iter_get_buffer (start) ==
 			      GTK_TEXT_BUFFER (job->priv->buffer) &&
 			      gtk_text_iter_get_buffer (end) ==
 			      GTK_TEXT_BUFFER (job->priv->buffer), FALSE);
@@ -2625,8 +2622,8 @@ gtk_source_print_job_print_range_async (GtkSourcePrintJob *job,
 void 
 gtk_source_print_job_cancel (GtkSourcePrintJob *job)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (job->priv->printing);
 
 	if (job->priv->idle_printing_tag > 0)
 	{
@@ -2661,7 +2658,7 @@ gtk_source_print_job_cancel (GtkSourcePrintJob *job)
 GnomePrintJob *
 gtk_source_print_job_get_print_job (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	if (job->priv->print_job)
 		g_object_ref (job->priv->print_job);
@@ -2683,8 +2680,8 @@ gtk_source_print_job_get_print_job (GtkSourcePrintJob *job)
 guint 
 gtk_source_print_job_get_page (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
-	g_return_val_if_fail (job->priv->printing, 0);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
+	cm_return_val_if_fail (job->priv->printing, 0);
 
 	return job->priv->page;
 }
@@ -2705,7 +2702,7 @@ gtk_source_print_job_get_page (GtkSourcePrintJob *job)
 guint 
 gtk_source_print_job_get_page_count (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), 0);
 
 	return job->priv->page_count;
 }
@@ -2727,8 +2724,8 @@ gtk_source_print_job_get_page_count (GtkSourcePrintJob *job)
 GnomePrintContext *
 gtk_source_print_job_get_print_context (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
-	g_return_val_if_fail (job->priv->printing, NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (job->priv->printing, NULL);
 
 	return job->priv->print_ctxt;
 }
@@ -2751,8 +2748,8 @@ strdup_strftime (const gchar *format, const struct tm *tm)
 	gsize convlen = 0;
 	GError *error = NULL;
 
-	g_return_val_if_fail (format != NULL, NULL);
-	g_return_val_if_fail (tm != NULL, NULL);
+	cm_return_val_if_fail (format != NULL, NULL);
+	cm_return_val_if_fail (tm != NULL, NULL);
 
 	locale_format = g_locale_from_utf8 (format, -1, NULL, &locale_format_len, &error);
 
@@ -2980,8 +2977,8 @@ void
 gtk_source_print_job_set_print_header (GtkSourcePrintJob *job,
 				       gboolean           setting)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	setting = (setting != FALSE);
 	
@@ -3007,7 +3004,7 @@ gtk_source_print_job_set_print_header (GtkSourcePrintJob *job,
 gboolean 
 gtk_source_print_job_get_print_header (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
 
 	return job->priv->print_header;
 }
@@ -3029,8 +3026,8 @@ void
 gtk_source_print_job_set_print_footer (GtkSourcePrintJob *job,
 				       gboolean           setting)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	setting = (setting != FALSE);
 	
@@ -3056,7 +3053,7 @@ gtk_source_print_job_set_print_footer (GtkSourcePrintJob *job,
 gboolean 
 gtk_source_print_job_get_print_footer (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), FALSE);
 
 	return job->priv->print_footer;
 }
@@ -3074,8 +3071,8 @@ void
 gtk_source_print_job_set_header_footer_font_desc (GtkSourcePrintJob    *job,
 						  PangoFontDescription *desc)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 	
 	if (desc)
 		desc = pango_font_description_copy (desc);
@@ -3108,8 +3105,8 @@ gtk_source_print_job_set_header_footer_font (GtkSourcePrintJob *job,
 {
 	PangoFontDescription *desc;
 	
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	if (font_name != NULL)
 	{
@@ -3137,7 +3134,7 @@ gtk_source_print_job_set_header_footer_font (GtkSourcePrintJob *job,
 PangoFontDescription *
 gtk_source_print_job_get_header_footer_font_desc (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	return job->priv->header_footer_font;
 }
@@ -3163,7 +3160,7 @@ gtk_source_print_job_get_header_footer_font_desc (GtkSourcePrintJob *job)
 gchar *
 gtk_source_print_job_get_header_footer_font (GtkSourcePrintJob *job)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
+	cm_return_val_if_fail (GTK_IS_SOURCE_PRINT_JOB (job), NULL);
 
 	if (job->priv->header_footer_font != NULL)
 		return font_description_to_gnome_font_name (job->priv->header_footer_font);
@@ -3200,8 +3197,8 @@ gtk_source_print_job_set_header_format (GtkSourcePrintJob *job,
 					const gchar       *right,
 					gboolean           separator)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	/* FIXME: validate given strings? */
 	g_free (job->priv->header_format_left);
@@ -3230,8 +3227,8 @@ gtk_source_print_job_set_footer_format (GtkSourcePrintJob *job,
 					const gchar       *right,
 					gboolean           separator)
 {
-	g_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
-	g_return_if_fail (!job->priv->printing);
+	cm_return_if_fail (GTK_IS_SOURCE_PRINT_JOB (job));
+	cm_return_if_fail (!job->priv->printing);
 
 	/* FIXME: validate given strings? */
 	g_free (job->priv->footer_format_left);
