@@ -351,13 +351,13 @@ static gboolean match_with_addresses_in_addressbook
 	gboolean found = FALSE;
 	gchar *path = NULL;
 
-	g_return_val_if_fail(address_list != NULL, FALSE);
+	cm_return_val_if_fail(address_list != NULL, FALSE);
 
 	debug_print("match_with_addresses_in_addressbook(%d, %s)\n",
 				g_slist_length(address_list), folderpath?folderpath:"(null)");
 
 	if (folderpath == NULL ||
-		strcasecmp(folderpath, _("Any")) == 0 ||
+		strcasecmp(folderpath, "Any") == 0 ||
 		*folderpath == '\0')
 		path = NULL;
 	else
@@ -463,6 +463,7 @@ static gboolean matcherprop_string_match(MatcherProp *prop, const gchar *str,
 	switch (prop->matchtype) {
 	case MATCHTYPE_REGEXPCASE:
 	case MATCHTYPE_REGEXP:
+#ifndef G_OS_WIN32
 		if (!prop->preg && (prop->error == 0)) {
 			prop->preg = g_new0(regex_t, 1);
 			/* if regexp then don't use the escaped string */
@@ -505,7 +506,7 @@ static gboolean matcherprop_string_match(MatcherProp *prop, const gchar *str,
 			g_free(stripped);
 		}
 		break;
-			
+#endif			
 	case MATCHTYPE_MATCHCASE:
 	case MATCHTYPE_MATCH:
 		ret = (strstr(str1, down_expr) != NULL);
@@ -1033,76 +1034,76 @@ gboolean matcherprop_match(MatcherProp *prop,
 	}
 	case MATCHCRITERIA_SIZE_GREATER:
 	{
-		/* FIXME: info->size is an off_t */
-		gboolean ret = (info->size > (off_t) prop->value);
+		/* FIXME: info->size is a goffset */
+		gboolean ret = (info->size > (goffset) prop->value);
 
 		/* debug output */
 		if (debug_filtering_session
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is greater than [ %d ]\n",
-						info->size, prop->value);
+						"message size is greater than [ %d ]\n",
+						prop->value);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is not greater than [ %d ]\n",
-						info->size, prop->value);
+						"message size is not greater than [ %d ]\n",
+						prop->value);
 			}
 		}
 		return ret;
 	}
 	case MATCHCRITERIA_SIZE_SMALLER:
 	{
-		/* FIXME: info->size is an off_t */
-		gboolean ret = (info->size < (off_t) prop->value);
+		/* FIXME: info->size is a goffset */
+		gboolean ret = (info->size < (goffset) prop->value);
 
 		/* debug output */
 		if (debug_filtering_session
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is smaller than [ %d ]\n",
-						info->size, prop->value);
+						"message size is smaller than [ %d ]\n",
+						prop->value);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is not smaller than [ %d ]\n",
-						info->size, prop->value);
+						"message size is not smaller than [ %d ]\n",
+						prop->value);
 			}
 		}
 		return ret;
 	}
 	case MATCHCRITERIA_SIZE_EQUAL:
 	{
-		/* FIXME: info->size is an off_t */
-		gboolean ret = (info->size == (off_t) prop->value);
+		/* FIXME: info->size is a goffset */
+		gboolean ret = (info->size == (goffset) prop->value);
 
 		/* debug output */
 		if (debug_filtering_session
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is equal to [ %d ]\n",
-						info->size, prop->value);
+						"message size is equal to [ %d ]\n",
+						prop->value);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message size [ %ld ] is not equal to [ %d ]\n",
-						info->size, prop->value);
+						"message size is not equal to [ %d ]\n",
+						prop->value);
 			}
 		}
 		return ret;
 	}
 	case MATCHCRITERIA_PARTIAL:
 	{
-		/* FIXME: info->size is an off_t */
-		gboolean ret = (info->total_size != 0 && info->size != (off_t)info->total_size);
+		/* FIXME: info->size is a goffset */
+		gboolean ret = (info->total_size != 0 && info->size != (goffset)info->total_size);
 
 		/* debug output */
 		if (debug_filtering_session
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message is partially downloaded, size [ %ld ] is less than total size [ %d ])\n",
-						info->size, info->total_size);
+						"message is partially downloaded, size is less than total size [ %d ])\n",
+						info->total_size);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
 						"message is not partially downloaded\n");
@@ -1112,8 +1113,8 @@ gboolean matcherprop_match(MatcherProp *prop,
 	}
 	case MATCHCRITERIA_NOT_PARTIAL:
 	{
-		/* FIXME: info->size is an off_t */
-		gboolean ret = (info->total_size == 0 || info->size == (off_t)info->total_size);
+		/* FIXME: info->size is a goffset */
+		gboolean ret = (info->total_size == 0 || info->size == (goffset)info->total_size);
 
 		/* debug output */
 		if (debug_filtering_session
@@ -1123,8 +1124,8 @@ gboolean matcherprop_match(MatcherProp *prop,
 						"message is not partially downloaded\n");
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message is partially downloaded, size [ %ld ] is less than total size [ %d ])\n",
-						info->size, info->total_size);
+						"message is partially downloaded, size is less than total size [ %d ])\n",
+						info->total_size);
 			}
 		}
 		return ret;
@@ -1205,10 +1206,11 @@ void matcherlist_free(MatcherList *cond)
 {
 	GSList *l;
 
-	g_return_if_fail(cond);
+	cm_return_if_fail(cond);
 	for (l = cond->matchers ; l != NULL ; l = g_slist_next(l)) {
 		matcherprop_free((MatcherProp *) l->data);
 	}
+	g_slist_free(cond->matchers);
 	g_free(cond);
 }
 
@@ -1274,9 +1276,9 @@ static gboolean matcherprop_match_one_header(MatcherProp *matcher,
 			gboolean found = FALSE;
 
 			/* how many address headers are me trying to mach? */
-			if (strcasecmp(matcher->header, _("Any")) == 0)
+			if (strcasecmp(matcher->header, "Any") == 0)
 				match = MATCH_ANY;
-			else if (strcasecmp(matcher->header, Q_("Filtering Matcher Menu|All")) == 0)
+			else if (strcasecmp(matcher->header, "All") == 0)
 					match = MATCH_ALL;
 
 			if (match == MATCH_ONE) {
@@ -1407,9 +1409,9 @@ static gboolean matcherlist_match_headers(MatcherList *matchers, FILE *fp)
 					 procheader_headername_equal(header->name, "Reply-To") ||
 					 procheader_headername_equal(header->name, "Sender"))) {
 
-					if (strcasecmp(matcher->header, _("Any")) == 0)
+					if (strcasecmp(matcher->header, "Any") == 0)
 						match = MATCH_ANY;
-					else if (strcasecmp(matcher->header, Q_("Filtering Matcher Menu|All")) == 0)
+					else if (strcasecmp(matcher->header, "All") == 0)
 						match = MATCH_ALL;
 					else
 						match = MATCH_ONE;
@@ -2001,9 +2003,9 @@ static void add_str_default(gchar ** dest,
 
 /* matching_build_command() - preferably cmd should be unescaped */
 /*!
- *\brief	Build the command line to execute
+ *\brief	Build the command-line to execute
  *
- *\param	cmd String with command line specifiers
+ *\param	cmd String with command-line specifiers
  *\param	info Message info to use for command
  *
  *\return	gchar * Newly allocated string
@@ -2370,8 +2372,17 @@ static void matcher_add_rulenames(const gchar *rcpath)
 	FILE *dst = g_fopen(newpath, "wb");
 	gchar buf[BUFFSIZE];
 	int r;
+	if (src == NULL) {
+		perror("fopen");
+		if (dst)
+			fclose(dst);
+		g_free(newpath);
+		return;
+	}
 	if (dst == NULL) {
 		perror("fopen");
+		if (src)
+			fclose(src);
 		g_free(newpath);
 		return;
 	}
