@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,20 +26,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkctree.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvpaned.h>
-#include <gtk/gtktext.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -88,10 +75,10 @@ typedef enum
 
 static void mimeview_set_multipart_tree		(MimeView	*mimeview,
 						 MimeInfo	*mimeinfo,
-						 GtkCTreeNode	*parent);
-static GtkCTreeNode *mimeview_append_part	(MimeView	*mimeview,
+						 GtkCMCTreeNode	*parent);
+static GtkCMCTreeNode *mimeview_append_part	(MimeView	*mimeview,
 						 MimeInfo	*partinfo,
-						 GtkCTreeNode	*parent);
+						 GtkCMCTreeNode	*parent);
 static void mimeview_show_message_part		(MimeView	*mimeview,
 						 MimeInfo	*partinfo);
 static void mimeview_change_view_type		(MimeView	*mimeview,
@@ -102,8 +89,8 @@ static gchar *mimeview_get_filename_for_part		(MimeInfo	*partinfo,
 static gboolean mimeview_write_part		(const gchar	*filename,
 						 MimeInfo	*partinfo);
 
-static void mimeview_selected		(GtkCTree	*ctree,
-					 GtkCTreeNode	*node,
+static void mimeview_selected		(GtkCMCTree	*ctree,
+					 GtkCMCTreeNode	*node,
 					 gint		 column,
 					 MimeView	*mimeview);
 static void mimeview_start_drag 	(GtkWidget	*widget,
@@ -132,10 +119,12 @@ static void mimeview_save_as		(MimeView	*mimeview);
 static void mimeview_save_all		(MimeView	*mimeview);
 static void mimeview_launch		(MimeView	*mimeview,
 					 MimeInfo	*partinfo);
+#ifndef G_OS_WIN32
 static void mimeview_open_with		(MimeView	*mimeview);
 static void mimeview_open_part_with	(MimeView	*mimeview,
 					 MimeInfo	*partinfo,
 					 gboolean	 automatic);
+#endif
 static void mimeview_select_next_part	(MimeView	*mimeview);
 static void mimeview_select_prev_part	(MimeView	*mimeview);
 static void mimeview_view_file		(const gchar	*filename,
@@ -168,20 +157,49 @@ static void icon_scroll_size_allocate_cb(GtkWidget 	*widget,
 					 MimeView 	*mimeview);
 static MimeInfo *mimeview_get_part_to_use(MimeView *mimeview);
 
-static void mimeview_launch_cb(MimeView *mimeview)
+static void mimeview_launch_cb(GtkAction *action, gpointer data)
 {
+	MimeView *mimeview = (MimeView *)data;
 	mimeview_launch(mimeview, mimeview_get_part_to_use(mimeview));
 }
-static GtkItemFactoryEntry mimeview_popup_entries[] =
+
+#ifndef G_OS_WIN32
+static void mimeview_open_with_cb(GtkAction *action, gpointer data)
 {
-	{N_("/_Open (l)"),		  NULL, mimeview_launch_cb,	  0, NULL},
-#ifndef MAEMO
-	{N_("/Open _with (o)..."),	  NULL, mimeview_open_with,	  0, NULL},
+	mimeview_open_with((MimeView *)data);
+}
 #endif
-	{N_("/_Display as text (t)"), 	  NULL, mimeview_display_as_text, 0, NULL},
-	{N_("/_Save as (y)..."),	  NULL, mimeview_save_as,	  0, NULL},
-	{N_("/Save _all..."),	 	  NULL, mimeview_save_all,	  0, NULL},
-	{N_("/Next part (a)"),	 	  NULL, mimeview_select_next_part,0, NULL},
+
+static void mimeview_display_as_text_cb(GtkAction *action, gpointer data)
+{
+	mimeview_display_as_text((MimeView *)data);
+}
+
+static void mimeview_save_as_cb(GtkAction *action, gpointer data)
+{
+	mimeview_save_as((MimeView *)data);
+}
+
+static void mimeview_save_all_cb(GtkAction *action, gpointer data)
+{
+	mimeview_save_all((MimeView *)data);
+}
+
+static void mimeview_select_next_part_cb(GtkAction *action, gpointer data)
+{
+	mimeview_select_next_part((MimeView *)data);
+}
+
+static GtkActionEntry mimeview_menu_actions[] = {
+	{ "MimeView", NULL, "MimeView" },
+	{ "MimeView/Open", NULL, N_("_Open (l)"), NULL, "Open MIME part", G_CALLBACK(mimeview_launch_cb) },
+#if (!defined MAEMO && !defined G_OS_WIN32)
+	{ "MimeView/OpenWith", NULL, N_("Open _with (o)..."), NULL, "Open MIME part with...", G_CALLBACK(mimeview_open_with_cb) },
+#endif
+	{ "MimeView/DisplayAsText", NULL, N_("_Display as text (t)"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
+	{ "MimeView/SaveAs", NULL, N_("_Save as (y)..."), NULL, "Save as", G_CALLBACK(mimeview_save_as_cb) },
+	{ "MimeView/SaveAll", NULL, N_("Save _all..."), NULL, "Save all parts", G_CALLBACK(mimeview_save_all_cb) },
+	{ "MimeView/NextPart", NULL, N_("Next part (a)"), NULL, "Next part", G_CALLBACK(mimeview_select_next_part_cb) }
 };
 
 static GtkTargetEntry mimeview_mime_types[] =
@@ -236,12 +254,12 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	GtkWidget *arrow;
 	GtkWidget *scrollbutton;
 	GtkWidget *hbox;
-	GtkTooltips *tooltips;
-	GtkItemFactory *popupfactory;
 	NoticeView *siginfoview;
+	GtkRequisition r;
+
 	gchar *titles[N_MIMEVIEW_COLS];
-	gint n_entries;
 	gint i;
+	CLAWS_TIP_DECL();
 
 	if (!hand_cursor)
 		hand_cursor = gdk_cursor_new(GDK_HAND2);
@@ -261,14 +279,14 @@ MimeView *mimeview_create(MainWindow *mainwin)
 
 	ctree = gtk_sctree_new_with_titles(N_MIMEVIEW_COLS, 0, titles);
 	gtk_widget_show(ctree);
-	gtk_clist_set_selection_mode(GTK_CLIST(ctree), GTK_SELECTION_BROWSE);
-	gtk_ctree_set_line_style(GTK_CTREE(ctree), GTK_CTREE_LINES_NONE);
-	gtk_clist_set_column_justification(GTK_CLIST(ctree), COL_SIZE,
+	gtk_cmclist_set_selection_mode(GTK_CMCLIST(ctree), GTK_SELECTION_BROWSE);
+	gtk_cmctree_set_line_style(GTK_CMCTREE(ctree), GTK_CMCTREE_LINES_NONE);
+	gtk_cmclist_set_column_justification(GTK_CMCLIST(ctree), COL_SIZE,
 					   GTK_JUSTIFY_RIGHT);
-	gtk_clist_set_column_width(GTK_CLIST(ctree), COL_MIMETYPE, 240);
-	gtk_clist_set_column_width(GTK_CLIST(ctree), COL_SIZE, 90);
+	gtk_cmclist_set_column_width(GTK_CMCLIST(ctree), COL_MIMETYPE, 240);
+	gtk_cmclist_set_column_width(GTK_CMCLIST(ctree), COL_SIZE, 90);
 	for (i = 0; i < N_MIMEVIEW_COLS; i++)
-		GTK_WIDGET_UNSET_FLAGS(GTK_CLIST(ctree)->column[i].button,
+		GTK_WIDGET_UNSET_FLAGS(GTK_CMCLIST(ctree)->column[i].button,
 				       GTK_CAN_FOCUS);
 	gtk_container_add(GTK_CONTAINER(scrolledwin), ctree);
 
@@ -317,6 +335,7 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	mimeview->ctree_mode = FALSE;
 	arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
 	gtk_widget_show(arrow);
+	gtk_widget_size_request(arrow, &r);
 	gtk_container_add(GTK_CONTAINER(mime_toggle), arrow);
 	g_signal_connect(G_OBJECT(mime_toggle), "button_release_event", 
 			 G_CALLBACK(mime_toggle_button_cb), mimeview);
@@ -333,11 +352,38 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	ctree_mainbox = gtk_hbox_new(FALSE, 0);	
 	gtk_box_pack_start(GTK_BOX(ctree_mainbox), scrolledwin, TRUE, TRUE, 0);
 
- 	n_entries = sizeof(mimeview_popup_entries) /
- 		sizeof(mimeview_popup_entries[0]);
- 	popupmenu = menu_create_items(mimeview_popup_entries, n_entries,
- 				      "<MimeView>", &popupfactory, mimeview);
-	tooltips = gtk_tooltips_new();
+	mimeview->ui_manager = gtk_ui_manager_new();
+	mimeview->action_group = cm_menu_create_action_group_full(mimeview->ui_manager,
+			"MimeView", mimeview_menu_actions,
+			G_N_ELEMENTS(mimeview_menu_actions), (gpointer)mimeview);
+
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, "/", "Menus", "Menus", GTK_UI_MANAGER_MENUBAR)
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/", "MimeView", "MimeView", GTK_UI_MANAGER_MENU);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "Open", "MimeView/Open",
+			GTK_UI_MANAGER_MENUITEM);
+#if (!defined MAEMO && !defined G_OS_WIN32)
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "OpenWith", "MimeView/OpenWith",
+			GTK_UI_MANAGER_MENUITEM);
+#endif
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "DisplayAsText", "MimeView/DisplayAsText",
+			GTK_UI_MANAGER_MENUITEM);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SaveAs", "MimeView/SaveAs",
+			GTK_UI_MANAGER_MENUITEM);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SaveAll", "MimeView/SaveAll",
+			GTK_UI_MANAGER_MENUITEM);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "NextPart", "MimeView/NextPart",
+			GTK_UI_MANAGER_MENUITEM);
+
+	popupmenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+				gtk_ui_manager_get_widget(mimeview->ui_manager, "/Menus/MimeView")) );
+
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
@@ -349,7 +395,6 @@ MimeView *mimeview_create(MainWindow *mainwin)
 
 	paned = gtk_vpaned_new();
 	gtk_widget_show(paned);
-	gtk_paned_set_gutter_size(GTK_PANED(paned), 0);
 	gtk_paned_pack1(GTK_PANED(paned), ctree_mainbox, FALSE, TRUE);
 	gtk_paned_pack2(GTK_PANED(paned), vbox, TRUE, TRUE);
 	
@@ -359,8 +404,8 @@ MimeView *mimeview_create(MainWindow *mainwin)
 
 	gtk_widget_show(hbox);
 	gtk_widget_hide(ctree_mainbox);
-#ifdef MAEMO
-	gtk_widget_set_size_request(mime_toggle, -1, arrow->requisition.height + 8);
+#ifdef GENERIC_UMPC
+	gtk_widget_set_size_request(mime_toggle, -1, r.height + 8);
 #endif
 	mimeview->hbox          = hbox;
 	mimeview->paned         = paned;
@@ -368,7 +413,6 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	mimeview->ctree         = ctree;
 	mimeview->mime_notebook = mime_notebook;
 	mimeview->popupmenu     = popupmenu;
-	mimeview->popupfactory  = popupfactory;
 	mimeview->type          = -1;
 	mimeview->ctree_mainbox = ctree_mainbox;
 	mimeview->icon_scroll   = icon_scroll;
@@ -376,7 +420,9 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	mimeview->icon_mainbox  = icon_mainbox;
 	mimeview->icon_count    = 0;
 	mimeview->mainwin       = mainwin;
-	mimeview->tooltips      = tooltips;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	mimeview->tooltips      = tips;
+#endif
 	mimeview->oldsize       = 60;
 	mimeview->mime_toggle   = mime_toggle;
 	mimeview->siginfoview	= siginfoview;
@@ -410,13 +456,13 @@ static gboolean any_part_is_signed(MimeInfo *mimeinfo)
 void mimeview_show_message(MimeView *mimeview, MimeInfo *mimeinfo,
 			   const gchar *file)
 {
-	GtkCTree *ctree = GTK_CTREE(mimeview->ctree);
-	GtkCTreeNode *node;
+	GtkCMCTree *ctree = GTK_CMCTREE(mimeview->ctree);
+	GtkCMCTreeNode *node;
 
 	mimeview_clear(mimeview);
 
-	g_return_if_fail(file != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(file != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	mimeview->mimeinfo = mimeinfo;
 
@@ -437,11 +483,11 @@ void mimeview_show_message(MimeView *mimeview, MimeInfo *mimeinfo,
 	g_signal_handlers_unblock_by_func(G_OBJECT(ctree),
 					  mimeview_selected, mimeview);
 
-	node = GTK_CTREE_NODE(GTK_CLIST(ctree)->row_list);
+	node = GTK_CMCTREE_NODE(GTK_CMCLIST(ctree)->row_list);
 	if (node) {
-		gtk_ctree_select(ctree, node);
+		gtk_cmctree_select(ctree, node);
 		icon_list_toggle_by_mime_info
-			(mimeview, gtk_ctree_node_get_row_data(ctree, node));
+			(mimeview, gtk_cmctree_node_get_row_data(ctree, node));
 		gtkut_ctree_set_focus_row(ctree, node);
 	}
 }
@@ -497,16 +543,16 @@ void mimeview_destroy(MimeView *mimeview)
 
 MimeInfo *mimeview_get_selected_part(MimeView *mimeview)
 {
-	return gtk_ctree_node_get_row_data
-		(GTK_CTREE(mimeview->ctree), mimeview->opened);
+	return gtk_cmctree_node_get_row_data
+		(GTK_CMCTREE(mimeview->ctree), mimeview->opened);
 }
 
 gint mimeview_get_selected_part_num(MimeView *mimeview)
 {
 	gint i = 0;
-	GList *rows = GTK_CLIST(mimeview->ctree)->row_list;
+	GList *rows = GTK_CMCLIST(mimeview->ctree)->row_list;
 	while (rows) {
-		if (mimeview->opened == GTK_CTREE_NODE(rows))
+		if (mimeview->opened == GTK_CMCTREE_NODE(rows))
 			return i;
 		i++;
 		rows = rows->next;
@@ -518,18 +564,18 @@ void mimeview_select_part_num(MimeView *mimeview, gint i)
 {
 	if (i < 0)
 		return;
-	gtk_clist_unselect_all(GTK_CLIST(mimeview->ctree));
-	gtk_clist_select_row(GTK_CLIST(mimeview->ctree), i, -1);
-	gtkut_clist_set_focus_row(GTK_CLIST(mimeview->ctree), i);
+	gtk_cmclist_unselect_all(GTK_CMCLIST(mimeview->ctree));
+	gtk_cmclist_select_row(GTK_CMCLIST(mimeview->ctree), i, -1);
+	gtkut_clist_set_focus_row(GTK_CMCLIST(mimeview->ctree), i);
 }
 
 static void mimeview_set_multipart_tree(MimeView *mimeview,
 					MimeInfo *mimeinfo,
-					GtkCTreeNode *parent)
+					GtkCMCTreeNode *parent)
 {
-	GtkCTreeNode *node;
+	GtkCMCTreeNode *node;
 
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	while (mimeinfo != NULL) {
 		node = mimeview_append_part(mimeview, mimeinfo, parent);
@@ -570,12 +616,12 @@ static const gchar *get_part_description(MimeInfo *partinfo)
 		return get_part_name(partinfo);
 }
 
-static GtkCTreeNode *mimeview_append_part(MimeView *mimeview,
+static GtkCMCTreeNode *mimeview_append_part(MimeView *mimeview,
 					  MimeInfo *partinfo,
-					  GtkCTreeNode *parent)
+					  GtkCMCTreeNode *parent)
 {
-	GtkCTree *ctree = GTK_CTREE(mimeview->ctree);
-	GtkCTreeNode *node;
+	GtkCMCTree *ctree = GTK_CMCTREE(mimeview->ctree);
+	GtkCMCTreeNode *node;
 	static gchar content_type[64];
 	gchar *str[N_MIMEVIEW_COLS];
 
@@ -586,16 +632,16 @@ static GtkCTreeNode *mimeview_append_part(MimeView *mimeview,
 	}
 
 	str[COL_MIMETYPE] = content_type;
-	str[COL_SIZE] = to_human_readable(partinfo->length);
+	str[COL_SIZE] = to_human_readable((goffset)partinfo->length);
 	if (prefs_common.attach_desc)
 		str[COL_NAME] = (gchar *) get_part_description(partinfo);
 	else
 		str[COL_NAME] = (gchar *) get_part_name(partinfo);
 
 	node = gtk_sctree_insert_node(ctree, parent, NULL, str, 0,
-				     NULL, NULL, NULL, NULL,
+				     NULL, NULL,
 				     FALSE, TRUE);
-	gtk_ctree_node_set_row_data(ctree, node, partinfo);
+	gtk_cmctree_node_set_row_data(ctree, node, partinfo);
 
 	return node;
 }
@@ -632,16 +678,16 @@ static MimeViewer *get_viewer_for_content_type(MimeView *mimeview, const gchar *
 	GSList *cur;
 	MimeViewerFactory *factory = NULL;
 	MimeViewer *viewer = NULL;
+	gchar *real_contenttype = NULL;
 
 /*
  * FNM_CASEFOLD is a GNU extension
- * if its not defined copy the string to the stack and
- * convert the copy to lower case
  */
 #ifndef FNM_CASEFOLD
 #define FNM_CASEFOLD 0
-	Xstrdup_a(content_type, content_type, return NULL);
-	g_strdown((gchar *)content_type);
+	real_contenttype = g_utf8_strdown((gchar *)content_type, -1);
+#else
+	real_contenttype = g_strdup(content_type);
 #endif
 	
 	for (cur = mimeviewer_factories; cur != NULL; cur = g_slist_next(cur)) {
@@ -649,7 +695,7 @@ static MimeViewer *get_viewer_for_content_type(MimeView *mimeview, const gchar *
 		gint i = 0;
 
 		while (curfactory->content_types[i] != NULL) {
-			if(!fnmatch(curfactory->content_types[i], content_type, FNM_CASEFOLD)) {
+			if(!fnmatch(curfactory->content_types[i], real_contenttype, FNM_CASEFOLD)) {
 				debug_print("%s\n", curfactory->content_types[i]);
 				factory = curfactory;
 				break;
@@ -659,6 +705,7 @@ static MimeViewer *get_viewer_for_content_type(MimeView *mimeview, const gchar *
 		if (factory != NULL)
 			break;
 	}
+	g_free(real_contenttype);
 	if (factory == NULL)
 		return NULL;
 
@@ -712,6 +759,11 @@ gboolean mimeview_show_part(MimeView *mimeview, MimeInfo *partinfo)
 {
 	MimeViewer *viewer;
 	
+	if (mimeview->messageview->partial_display_shown) {
+		noticeview_hide(mimeview->messageview->noticeview);
+		mimeview->messageview->partial_display_shown = FALSE;
+	}
+
 	viewer = get_viewer_for_mimeinfo(mimeview, partinfo);
 	if (viewer == NULL) {
 		if (mimeview->mimeviewer != NULL)
@@ -766,7 +818,7 @@ static void mimeview_change_view_type(MimeView *mimeview, MimeViewType type)
 
 void mimeview_clear(MimeView *mimeview)
 {
-	GtkCList *clist = NULL;
+	GtkCMCList *clist = NULL;
 	
 	if (!mimeview)
 		return;
@@ -774,11 +826,11 @@ void mimeview_clear(MimeView *mimeview)
 	if (g_slist_find(mimeviews, mimeview) == NULL)
 		return;
 	
-	clist = GTK_CLIST(mimeview->ctree);
+	clist = GTK_CMCLIST(mimeview->ctree);
 	
 	noticeview_hide(mimeview->siginfoview);
 
-	gtk_clist_clear(clist);
+	gtk_cmclist_clear(clist);
 	textview_clear(mimeview->textview);
 	if (mimeview->mimeviewer != NULL)
 		mimeview->mimeviewer->clear_viewer(mimeview->mimeviewer);
@@ -808,8 +860,8 @@ static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo,
 	StockPixmap icon = STOCK_PIXMAP_PRIVACY_SIGNED;
 	SignatureStatus mycode = SIGNATURE_UNCHECKED;
 	
-	g_return_if_fail(mimeview != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 	
 	if (special)
 		mycode = code;
@@ -832,6 +884,11 @@ static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo,
 		func = display_full_info_cb;
 		icon = STOCK_PIXMAP_PRIVACY_WARN;
 		break;
+	case SIGNATURE_KEY_EXPIRED:
+		button_text = _("View full information");
+		func = display_full_info_cb;
+		icon = STOCK_PIXMAP_PRIVACY_EXPIRED;
+		break;
 	case SIGNATURE_INVALID:
 		button_text = _("View full information");
 		func = display_full_info_cb;
@@ -1088,9 +1145,9 @@ static void mimeview_check_signature(MimeView *mimeview)
 static void redisplay_email(GtkWidget *widget, gpointer user_data)
 {
 	MimeView *mimeview = (MimeView *) user_data;
-	GtkCTreeNode *node = mimeview->opened;
+	GtkCMCTreeNode *node = mimeview->opened;
 	mimeview->opened = NULL;
-	mimeview_selected(GTK_CTREE(mimeview->ctree), node, 0, mimeview);
+	mimeview_selected(GTK_CMCTREE(mimeview->ctree), node, 0, mimeview);
 }
 
 static void display_full_info_cb(GtkWidget *widget, gpointer user_data)
@@ -1114,8 +1171,8 @@ static void update_signature_info(MimeView *mimeview, MimeInfo *selected)
 	MimeInfo *siginfo;
 	MimeInfo *first_text;
 	
-	g_return_if_fail(mimeview != NULL);
-	g_return_if_fail(selected != NULL);
+	cm_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(selected != NULL);
 	
 	if (selected->type == MIMETYPE_MESSAGE 
 	&&  !g_ascii_strcasecmp(selected->subtype, "rfc822")) {
@@ -1147,16 +1204,16 @@ static void update_signature_info(MimeView *mimeview, MimeInfo *selected)
 	noticeview_show(mimeview->siginfoview);
 }
 
-static void mimeview_selected(GtkCTree *ctree, GtkCTreeNode *node, gint column,
+static void mimeview_selected(GtkCMCTree *ctree, GtkCMCTreeNode *node, gint column,
 			      MimeView *mimeview)
 {
 	MimeInfo *partinfo;
 	if (mimeview->opened == node) return;
 	mimeview->opened = node;
 	mimeview->spec_part = NULL;
-	gtk_ctree_node_moveto(ctree, node, -1, 0.5, 0);
+	gtk_cmctree_node_moveto(ctree, node, -1, 0.5, 0);
 
-	partinfo = gtk_ctree_node_get_row_data(ctree, node);
+	partinfo = gtk_cmctree_node_get_row_data(ctree, node);
 	if (!partinfo) return;
 
 	/* ungrab the mouse event */
@@ -1194,7 +1251,7 @@ static void mimeview_start_drag(GtkWidget *widget, gint button,
 	GdkDragContext *context;
 	MimeInfo *partinfo;
 
-	g_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(mimeview != NULL);
 
 	partinfo = mimeview_get_selected_part(mimeview);
 	if (partinfo->disposition == DISPOSITIONTYPE_INLINE) return;
@@ -1207,17 +1264,17 @@ static void mimeview_start_drag(GtkWidget *widget, gint button,
 static gint mimeview_button_pressed(GtkWidget *widget, GdkEventButton *event,
 				    MimeView *mimeview)
 {
-	GtkCList *clist = GTK_CLIST(widget);
+	GtkCMCList *clist = GTK_CMCLIST(widget);
 	gint row, column;
 
 	if (!event) return FALSE;
 
 	if (event->button == 2 || event->button == 3) {
-		if (!gtk_clist_get_selection_info(clist, event->x, event->y,
+		if (!gtk_cmclist_get_selection_info(clist, event->x, event->y,
 						  &row, &column))
 			return FALSE;
-		gtk_clist_unselect_all(clist);
-		gtk_clist_select_row(clist, row, column);
+		gtk_cmclist_unselect_all(clist);
+		gtk_cmclist_select_row(clist, row, column);
 		gtkut_clist_set_focus_row(clist, row);
 	}
 	part_button_pressed(mimeview, event, mimeview_get_selected_part(mimeview));
@@ -1256,19 +1313,17 @@ static gboolean part_button_pressed(MimeView *mimeview, GdkEventButton *event,
 		if (partinfo && (partinfo->type == MIMETYPE_MESSAGE ||
 				 partinfo->type == MIMETYPE_IMAGE ||
 				 partinfo->type == MIMETYPE_MULTIPART))
-			menu_set_sensitive(mimeview->popupfactory,
-					   "/Display as text (t)", FALSE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/DisplayAsText", FALSE);
 		else
-			menu_set_sensitive(mimeview->popupfactory,
-					   "/Display as text (t)", TRUE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/DisplayAsText", TRUE);
+#ifndef G_OS_WIN32
 		if (partinfo &&
 		    partinfo->type == MIMETYPE_APPLICATION &&
 		    !g_ascii_strcasecmp(partinfo->subtype, "octet-stream"))
-			menu_set_sensitive(mimeview->popupfactory,
-					   "/Open (l)", FALSE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/Open", FALSE);
 		else
-			menu_set_sensitive(mimeview->popupfactory,
-					   "/Open (l)", TRUE);
+#endif
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/Open", TRUE);
 
 		g_object_set_data(G_OBJECT(mimeview->popupmenu),
 				  "pop_partinfo", partinfo);
@@ -1292,17 +1347,17 @@ void mimeview_pass_key_press_event(MimeView *mimeview, GdkEventKey *event)
 
 static void mimeview_select_next_part(MimeView *mimeview)
 {
-	GtkCTree *ctree = GTK_CTREE(mimeview->ctree);
-	GtkCTreeNode *node = mimeview->opened;
+	GtkCMCTree *ctree = GTK_CMCTREE(mimeview->ctree);
+	GtkCMCTreeNode *node = mimeview->opened;
 	MimeInfo *partinfo = NULL;
 	
 skip:
-	node = GTK_CTREE_NODE_NEXT(node);
+	node = GTK_CMCTREE_NODE_NEXT(node);
 	if (!node)
-		node = gtk_ctree_node_nth(GTK_CTREE(ctree), 0);
+		node = gtk_cmctree_node_nth(GTK_CMCTREE(ctree), 0);
 
 	if (node) {
-		partinfo = gtk_ctree_node_get_row_data(ctree, node);
+		partinfo = gtk_cmctree_node_get_row_data(ctree, node);
 		if (partinfo->type == MIMETYPE_MULTIPART)
 			goto skip;
 		gtk_sctree_unselect_all(GTK_SCTREE(ctree));
@@ -1313,17 +1368,17 @@ skip:
 
 static void mimeview_select_prev_part(MimeView *mimeview)
 {
-	GtkCTree *ctree = GTK_CTREE(mimeview->ctree);
-	GtkCTreeNode *node = mimeview->opened;
+	GtkCMCTree *ctree = GTK_CMCTREE(mimeview->ctree);
+	GtkCMCTreeNode *node = mimeview->opened;
 	MimeInfo *partinfo = NULL;
 	
 skip:
-	node = GTK_CTREE_NODE_PREV(node);
+	node = GTK_CMCTREE_NODE_PREV(node);
 	if (!node)
-		node = gtk_ctree_node_nth(GTK_CTREE(ctree), GTK_CLIST(ctree)->rows - 1);
+		node = gtk_cmctree_node_nth(GTK_CMCTREE(ctree), GTK_CMCLIST(ctree)->rows - 1);
 
 	if (node) {
-		partinfo = gtk_ctree_node_get_row_data(ctree, node);
+		partinfo = gtk_cmctree_node_get_row_data(ctree, node);
 		if (partinfo->type == MIMETYPE_MULTIPART)
 			goto skip;
 		gtk_sctree_unselect_all(GTK_SCTREE(ctree));
@@ -1343,7 +1398,7 @@ static gint mimeview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 				 MimeView *mimeview)
 {
 	SummaryView *summaryview;
-	GtkCTree *ctree = GTK_CTREE(widget);
+	GtkCMCTree *ctree = GTK_CMCTREE(widget);
 
 	if (!event) return FALSE;
 	if (!mimeview->opened) return FALSE;
@@ -1399,7 +1454,9 @@ static gint mimeview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 	case GDK_o:
 		BREAK_ON_MODIFIER_KEY();
 		KEY_PRESS_EVENT_STOP();
+#ifndef G_OS_WIN32
 		mimeview_open_with(mimeview);
+#endif
 		return TRUE;
 	case GDK_c:
 		BREAK_ON_MODIFIER_KEY();
@@ -1431,6 +1488,7 @@ static void mimeview_drag_data_get(GtkWidget	    *widget,
 	gchar *filename = NULL, *uriname, *tmp;
 	MimeInfo *partinfo;
 	gint err;
+	gint count = 0;
 
 	if (!mimeview->opened) return;
 	if (!mimeview->file) return;
@@ -1484,6 +1542,30 @@ static void mimeview_drag_data_get(GtkWidget	    *widget,
 	filename = g_strconcat(get_mime_tmp_dir(), G_DIR_SEPARATOR_S,
 			       tmp, NULL);
 
+check_new_file:
+	if (is_file_exist(filename)) {
+		gchar *ext = NULL;
+		gchar *prefix = NULL;
+		gchar *new_name = NULL;
+		if (strrchr(tmp, '.')) {
+			prefix = g_strdup(tmp);
+			ext = g_strdup(strrchr(tmp, '.'));
+			*(strrchr(prefix, '.')) = '\0';
+		} else {
+			prefix = g_strdup(tmp);
+			ext = g_strdup("");
+		}
+		count++;
+		new_name = g_strdup_printf("%s.%d%s", prefix, count, ext);
+		g_free(prefix);
+		g_free(ext);
+		g_free(filename);
+		filename = g_strconcat(get_mime_tmp_dir(), G_DIR_SEPARATOR_S,
+			       new_name, NULL);
+		g_free(new_name);
+		goto check_new_file;
+	}
+
 	g_free(tmp);
 
 	if ((err = procmime_get_part(filename, partinfo)) < 0)
@@ -1528,7 +1610,7 @@ static gchar *mimeview_get_filename_for_part(MimeInfo *partinfo,
 	subst_for_filename(filename);
 
 	fullname = g_strconcat
-		(basedir, G_DIR_SEPARATOR_S, (filename[0] == G_DIR_SEPARATOR)
+		(basedir, G_DIR_SEPARATOR_S, (g_path_is_absolute(filename))
 		 ? &filename[1] : filename, NULL);
 
 	g_free(filename);
@@ -1614,6 +1696,7 @@ static void mimeview_save_all(MimeView *mimeview)
 		alertpanel_error(_("'%s' is not a directory."),
 				 dirname);
 		g_free(startdir);
+		g_free(dirname);
 		return;
 	}
 
@@ -1647,6 +1730,7 @@ static void mimeview_save_all(MimeView *mimeview)
 	g_free(startdir);
 	prefs_common.attach_save_dir = g_filename_to_utf8(dirname,
 					-1, NULL, NULL, NULL);
+	g_free(dirname);
 }
 
 static MimeInfo *mimeview_get_part_to_use(MimeView *mimeview)
@@ -1685,7 +1769,7 @@ static void mimeview_save_as(MimeView *mimeview)
 
 	partinfo = mimeview_get_part_to_use(mimeview);
 
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 	
 	if (get_part_name(partinfo) == NULL) {
 		return;
@@ -1707,7 +1791,7 @@ static void mimeview_save_as(MimeView *mimeview)
 
 	subst_for_filename(partname);
 	
-	if (prefs_common.attach_save_dir)
+	if (prefs_common.attach_save_dir && *prefs_common.attach_save_dir)
 		filepath = g_strconcat(prefs_common.attach_save_dir,
 				       G_DIR_SEPARATOR_S, partname, NULL);
 	else
@@ -1741,7 +1825,7 @@ static void mimeview_display_as_text(MimeView *mimeview)
 
 	partinfo = mimeview_get_part_to_use(mimeview);
 	mimeview_select_mimepart_icon(mimeview, partinfo);
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 	mimeview_show_message_part(mimeview, partinfo);
 }
 
@@ -1756,7 +1840,7 @@ static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 	if (!partinfo)
 		partinfo = mimeview_get_part_to_use(mimeview);
 
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 
 	filename = procmime_get_tmp_file_name(partinfo);
 
@@ -1770,6 +1854,7 @@ static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 	g_free(filename);
 }
 
+#ifndef G_OS_WIN32
 static void mimeview_open_with(MimeView *mimeview)
 {
 	MimeInfo *partinfo;
@@ -1798,7 +1883,7 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 	gchar *uri;
 	int r = 0;
 #endif
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 
 	filename = procmime_get_tmp_file_name(partinfo);
 
@@ -1869,14 +1954,14 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 		if (content_type != NULL)
 			cmd = input_dialog_combo_remember
 				(_("Open with"),
-				 _("Enter the command line to open file:\n"
+				 _("Enter the command-line to open file:\n"
 				   "('%s' will be replaced with file name)"),
 				 mime_command ? mime_command : prefs_common.mime_open_cmd,
 				 prefs_common.mime_open_cmd_history, &remember);
 		else
 			cmd = input_dialog_combo
 				(_("Open with"),
-				 _("Enter the command line to open file:\n"
+				 _("Enter the command-line to open file:\n"
 				   "('%s' will be replaced with file name)"),
 				 mime_command ? mime_command : prefs_common.mime_open_cmd,
 				 prefs_common.mime_open_cmd_history);
@@ -1900,10 +1985,12 @@ out:
 	g_free(content_type);
 	g_free(filename);
 }
+#endif
 
 static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			       const gchar *cmd, MimeView *mimeview)
 {
+#ifndef G_OS_WIN32
 	gchar *p;
 	gchar buf[BUFFSIZE];
 	if (cmd == NULL)
@@ -1917,7 +2004,7 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			else
 				g_chmod(filename, S_IRUSR|S_IWUSR);
  		} else {
-			g_warning("MIME viewer command line is invalid: '%s'", cmd);
+			g_warning("MIME viewer command-line is invalid: '%s'", cmd);
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
  		}
 		if (execute_command_line(buf, TRUE) != 0) {
@@ -1926,6 +2013,24 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
 		}
 	}
+#else
+	SHFILEINFO file_info;
+	if ((SHGetFileInfo(filename, 0, &file_info, sizeof(SHFILEINFO), SHGFI_EXETYPE)) != 0) {
+		AlertValue val = alertpanel_full(_("Execute untrusted binary?"), 
+				      _("This attachment is an executable file. Executing "
+				        "untrusted binaries is dangerous and could probably "
+					"lead to compromission of your computer.\n\n"
+					"Do you want to run this file?"), GTK_STOCK_CANCEL, 
+					_("Run binary"),
+		      		      NULL, FALSE, NULL, ALERT_WARNING, G_ALERTDEFAULT);
+		if (val == G_ALERTALTERNATE) {
+			debug_print("executing binary\n");
+			ShellExecute(NULL, "open", filename, NULL, NULL, SW_SHOW);
+		}
+	} else
+		ShellExecute(NULL, "open", filename, NULL, NULL, SW_SHOW);
+	
+#endif
 }
 
 void mimeview_register_viewer_factory(MimeViewerFactory *factory)
@@ -1981,11 +2086,11 @@ static gboolean icon_clicked_cb (GtkWidget *button, GdkEventButton *event, MimeV
 
 static void icon_selected (MimeView *mimeview, gint num, MimeInfo *partinfo)
 {
-	GtkCTreeNode *node;
-	node = gtk_ctree_find_by_row_data(GTK_CTREE(mimeview->ctree), NULL, partinfo);
+	GtkCMCTreeNode *node;
+	node = gtk_cmctree_find_by_row_data(GTK_CMCTREE(mimeview->ctree), NULL, partinfo);
 
 	if (node)
-		gtk_ctree_select(GTK_CTREE(mimeview->ctree), node);
+		gtk_cmctree_select(GTK_CMCTREE(mimeview->ctree), node);
 }		
 
 void mimeview_select_mimepart_icon(MimeView *mimeview, MimeInfo *partinfo)
@@ -2051,10 +2156,12 @@ static gint icon_key_pressed(GtkWidget *button, GdkEventKey *event,
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_launch(mimeview, NULL);
 		return TRUE;
+#ifndef G_OS_WIN32
 	case GDK_o:
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_open_with(mimeview);
 		return TRUE;
+#endif
 	case GDK_c:
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_check_signature(mimeview);
@@ -2099,6 +2206,12 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	MimeInfo *partinfo;
 	MimeInfo *siginfo = NULL;
 	MimeInfo *encrypted = NULL;
+#ifdef GENERIC_UMPC
+	GtkRequisition r;
+#endif
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = mimeview->tooltips;
+#endif
 	
 	vbox = mimeview->icon_vbox;
 	mimeview->icon_count++;
@@ -2184,6 +2297,7 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_PASSED, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
 		case SIGNATURE_WARN:
+		case SIGNATURE_KEY_EXPIRED:
 			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_WARN, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
@@ -2212,7 +2326,7 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 						     mimeinfo->subtype);
 
 	tip = g_strjoin("\n", content_type,
-			to_human_readable(mimeinfo->length), NULL);
+			to_human_readable((goffset)mimeinfo->length), NULL);
 	g_free(content_type);
 	if (desc && *desc) {
 		gchar *tmp = NULL;
@@ -2233,7 +2347,7 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	}
 	g_free(sigshort);
 
-	gtk_tooltips_set_tip(mimeview->tooltips, button, tip, NULL);
+	CLAWS_SET_TIP(button, tip);
 	g_free(tip);
 	gtk_widget_show_all(button);
 	gtk_drag_source_set(button, GDK_BUTTON1_MASK|GDK_BUTTON3_MASK, 
@@ -2254,25 +2368,24 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	g_signal_connect(G_OBJECT(button), "drag_data_get",
 			 G_CALLBACK(mimeview_drag_data_get), mimeview);
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-#ifdef MAEMO
-	gtk_widget_set_size_request(vbox, -1, pixmap->requisition.height + 8);
-	gtk_widget_set_size_request(button, -1, pixmap->requisition.height + 4);
+#ifdef GENERIC_UMPC
+	gtk_widget_size_request(pixmap, &r);
+	gtk_widget_set_size_request(button, -1, r.height + 4);
 #endif
 
 }
 
 static void icon_list_clear (MimeView *mimeview)
 {
-	GList     *child;
+	GList     *child, *orig;
 	GtkAdjustment *adj;
 		
-	child = gtk_container_children(GTK_CONTAINER(mimeview->icon_vbox));
-	for (; child != NULL; child = g_list_next(child)) {
+	orig = gtk_container_get_children(GTK_CONTAINER(mimeview->icon_vbox));
+	for (child = orig; child != NULL; child = g_list_next(child)) {
 		gtkut_container_remove(GTK_CONTAINER(mimeview->icon_vbox), 
 				       GTK_WIDGET(child->data));
-		gtk_widget_destroy(GTK_WIDGET(child->data));
 	}
-	g_list_free(child);
+	g_list_free(orig);
 	mimeview->icon_count = 0;
 	adj  = gtk_layout_get_vadjustment(GTK_LAYOUT(mimeview->icon_scroll));
 	gtk_adjustment_set_value(adj, adj->lower);
@@ -2291,7 +2404,7 @@ static void icon_scroll_size_allocate_cb(GtkWidget *widget,
 	GtkAllocation *vbox_size;
 	GtkAllocation *layout_size;
 	GtkAdjustment *adj;
-	
+
 	adj = gtk_layout_get_vadjustment(GTK_LAYOUT(mimeview->icon_scroll));
 
 	mainbox_size = &mimeview->icon_mainbox->allocation;
@@ -2308,7 +2421,7 @@ static void icon_list_create(MimeView *mimeview, MimeInfo *mimeinfo)
 {
 	GtkRequisition size;
 
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	while (mimeinfo != NULL) {
 		if (mimeinfo->type != MIMETYPE_MULTIPART)
@@ -2332,7 +2445,7 @@ static void icon_list_toggle_by_mime_info (MimeView	*mimeview,
 {
 	GList *child;
 	
-	child = gtk_container_children(GTK_CONTAINER(mimeview->icon_vbox));
+	child = gtk_container_get_children(GTK_CONTAINER(mimeview->icon_vbox));
 	for (; child != NULL; child = g_list_next(child)) {
 		if (!GTK_IS_EVENT_BOX(child->data))
 			continue;
@@ -2356,13 +2469,13 @@ static void icon_list_toggle_by_mime_info (MimeView	*mimeview,
 static gint mime_toggle_button_cb(GtkWidget *button, GdkEventButton *event,
 				    MimeView *mimeview)
 {
-	gtk_widget_ref(button); 
+	g_object_ref(button); 
 
 	mimeview_leave_notify(button, NULL, NULL);
 
 	mimeview->ctree_mode = !mimeview->ctree_mode;
 	if (mimeview->ctree_mode) {
-		gtk_arrow_set(GTK_ARROW(GTK_BIN(button)->child), GTK_ARROW_RIGHT, 
+		gtk_arrow_set(GTK_ARROW(gtk_bin_get_child(GTK_BIN((button)))), GTK_ARROW_RIGHT, 
 					GTK_SHADOW_NONE);
 		gtk_widget_hide(mimeview->icon_mainbox);
 		gtk_widget_show(mimeview->ctree_mainbox);
@@ -2372,9 +2485,8 @@ static gint mime_toggle_button_cb(GtkWidget *button, GdkEventButton *event,
 					button);
 		gtk_box_pack_end(GTK_BOX(mimeview->ctree_mainbox), 
 				   button, FALSE, FALSE, 0);
-		gtk_paned_set_gutter_size(GTK_PANED(mimeview->paned), 6);
 	} else {
-		gtk_arrow_set(GTK_ARROW(GTK_BIN(button)->child), GTK_ARROW_LEFT, 
+		gtk_arrow_set(GTK_ARROW(gtk_bin_get_child(GTK_BIN((button)))), GTK_ARROW_LEFT, 
 			      GTK_SHADOW_NONE);
 		mimeview->oldsize = mimeview->ctree_mainbox->allocation.height;
 		gtk_widget_hide(mimeview->ctree_mainbox);
@@ -2388,12 +2500,11 @@ static gint mime_toggle_button_cb(GtkWidget *button, GdkEventButton *event,
 		gtk_box_reorder_child(GTK_BOX(button->parent), button, 0);
 		if (mimeview->opened)
 			icon_list_toggle_by_mime_info
-				(mimeview, gtk_ctree_node_get_row_data(GTK_CTREE(mimeview->ctree), 
+				(mimeview, gtk_cmctree_node_get_row_data(GTK_CMCTREE(mimeview->ctree), 
 								       mimeview->opened));
 
-		gtk_paned_set_gutter_size(GTK_PANED(mimeview->paned), 0);
 	}
-	gtk_widget_unref(button);
+	g_object_unref(button);
 	return TRUE;
 }
 
@@ -2429,8 +2540,10 @@ void mimeview_handle_cmd(MimeView *mimeview, const gchar *cmd, GdkEventButton *e
 		mimeview_save_as(mimeview);
 	else if (!strcmp(cmd, "sc://display_as_text"))
 		mimeview_display_as_text(mimeview);
+#ifndef G_OS_WIN32
 	else if (!strcmp(cmd, "sc://open_with"))
 		mimeview_open_with(mimeview);
+#endif
 	else if (!strcmp(cmd, "sc://open"))
 		mimeview_launch(mimeview, NULL);
 	else if (!strcmp(cmd, "sc://select_attachment") && data != NULL) {
