@@ -1,7 +1,7 @@
 /*
  * Claws Mail templates subsystem 
  * Copyright (C) 2001 Alexander Barinov
- * Copyright (C) 2001-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 2001-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,18 +99,22 @@ static gint prefs_template_deleted_cb		(GtkWidget	*widget,
 static gboolean prefs_template_key_pressed_cb	(GtkWidget	*widget,
 						 GdkEventKey	*event,
 						 gpointer	 data);
-static void prefs_template_cancel_cb		(void);
-static void prefs_template_ok_cb		(void);
-static void prefs_template_register_cb		(void);
-static void prefs_template_substitute_cb	(void);
-static void prefs_template_delete_cb		(void);
-static void prefs_template_delete_all_cb	(void);
-static void prefs_template_clear_cb		(void);
-static void prefs_template_duplicate_cb	(void);
-static void prefs_template_top_cb		(void);
-static void prefs_template_up_cb		(void);
-static void prefs_template_down_cb	(void);
-static void prefs_template_bottom_cb	(void);
+static gboolean prefs_template_search_func_cb (GtkTreeModel *model, gint column, 
+						const gchar *key, GtkTreeIter *iter, 
+						gpointer search_data);
+
+static void prefs_template_cancel_cb		(gpointer action, gpointer data);
+static void prefs_template_ok_cb		(gpointer action, gpointer data);
+static void prefs_template_register_cb		(gpointer action, gpointer data);
+static void prefs_template_substitute_cb	(gpointer action, gpointer data);
+static void prefs_template_delete_cb		(gpointer action, gpointer data);
+static void prefs_template_delete_all_cb	(gpointer action, gpointer data);
+static void prefs_template_clear_cb		(gpointer action, gpointer data);
+static void prefs_template_duplicate_cb		(gpointer action, gpointer data);
+static void prefs_template_top_cb		(gpointer action, gpointer data);
+static void prefs_template_up_cb		(gpointer action, gpointer data);
+static void prefs_template_down_cb		(gpointer action, gpointer data);
+static void prefs_template_bottom_cb		(gpointer action, gpointer data);
 
 static GtkListStore* prefs_template_create_data_store	(void);
 static void prefs_template_list_view_insert_template	(GtkWidget *list_view,
@@ -139,7 +143,7 @@ void prefs_template_open(void)
 static void prefs_template_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.templateswin_width = allocation->width;
 	prefs_common.templateswin_height = allocation->height;
@@ -180,7 +184,7 @@ static void prefs_template_window_create(void)
 	GtkWidget         *ok_btn;
 	static GdkGeometry geometry;
 	gint i;
-	GtkTooltips *tooltips;
+	CLAWS_TIP_DECL();
 
 	debug_print("Creating templates configuration window...\n");
 
@@ -219,7 +223,6 @@ static void prefs_template_window_create(void)
 	gtk_widget_show(table);
 	gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, FALSE, 0);
 
-	tooltips = gtk_tooltips_new();
 
 	for (i=0; widgets_table[i].label; i++) {
 
@@ -237,12 +240,8 @@ static void prefs_template_window_create(void)
 		gtk_table_attach(GTK_TABLE(table), *(widgets_table[i].entry), 1, 2, i, (i + 1),
 				(GtkAttachOptions) (GTK_EXPAND|GTK_SHRINK|GTK_FILL),
 				(GtkAttachOptions) 0, 0, 0);
-		gtk_tooltips_set_tip(tooltips, *(widgets_table[i].entry),
-				widgets_table[i].tooltips, NULL);
-
-		if (widgets_table[i].compl)
-			address_completion_register_entry(
-				GTK_ENTRY(*(widgets_table[i].entry)), TRUE);
+		CLAWS_SET_TIP(*(widgets_table[i].entry),
+				widgets_table[i].tooltips);
 	}
 
 	/* template content */
@@ -267,7 +266,7 @@ static void prefs_template_window_create(void)
 		}
 	}
 	gtk_widget_show(text_value);
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	gtk_widget_set_size_request(text_value, -1, 120);
 #else
 	gtk_widget_set_size_request(text_value, -1, 60);
@@ -301,8 +300,8 @@ static void prefs_template_window_create(void)
 	gtk_box_pack_start(GTK_BOX(hbox3), reg_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (reg_btn), "clicked",
 			 G_CALLBACK (prefs_template_register_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), reg_btn,
-			_("Append the new template above to the list"), NULL);
+	CLAWS_SET_TIP(reg_btn,
+			_("Append the new template above to the list"));
 
 	subst_btn = gtkut_get_replace_btn(_("Replace"));
 	gtk_widget_show(subst_btn);
@@ -310,24 +309,24 @@ static void prefs_template_window_create(void)
 	g_signal_connect(G_OBJECT(subst_btn), "clicked",
 			 G_CALLBACK(prefs_template_substitute_cb),
 			 NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), subst_btn,
-			_("Replace the selected template in list with the template above"), NULL);
+	CLAWS_SET_TIP(subst_btn,
+			_("Replace the selected template in list with the template above"));
 
 	del_btn = gtk_button_new_from_stock(GTK_STOCK_DELETE);
 	gtk_widget_show(del_btn);
 	gtk_box_pack_start(GTK_BOX(hbox3), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(del_btn), "clicked",
 			 G_CALLBACK(prefs_template_delete_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), del_btn,
-			_("Delete the selected template from the list"), NULL);
+	CLAWS_SET_TIP(del_btn,
+			_("Delete the selected template from the list"));
 
 	clear_btn = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
 	gtk_widget_show (clear_btn);
 	gtk_box_pack_start (GTK_BOX (hbox3), clear_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (clear_btn), "clicked",
 			G_CALLBACK(prefs_template_clear_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), clear_btn,
-			_("Clear all the input fields in the dialog"), NULL);
+	CLAWS_SET_TIP(clear_btn,
+			_("Clear all the input fields in the dialog"));
 
 #if GTK_CHECK_VERSION(2, 8, 0)
 	desc_btn = gtk_button_new_from_stock(GTK_STOCK_INFO);
@@ -338,8 +337,8 @@ static void prefs_template_window_create(void)
 	gtk_box_pack_end(GTK_BOX(hbox2), desc_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(desc_btn), "clicked",
 			 G_CALLBACK(quote_fmt_quote_description), window);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), desc_btn,
-			_("Show information on configuring templates"), NULL);
+	CLAWS_SET_TIP(desc_btn,
+			_("Show information on configuring templates"));
 
 	/* templates list */
 	hbox4 = gtk_hbox_new(FALSE, 8);
@@ -362,8 +361,8 @@ static void prefs_template_window_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox3), top_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(top_btn), "clicked",
 			 G_CALLBACK(prefs_template_top_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), top_btn,
-			_("Move the selected template to the top"), NULL);
+	CLAWS_SET_TIP(top_btn,
+			_("Move the selected template to the top"));
 
 	PACK_VSPACER(vbox3, spc_vbox, VSPACING_NARROW_2);
 
@@ -372,16 +371,16 @@ static void prefs_template_window_create(void)
 	gtk_box_pack_start (GTK_BOX(vbox3), up_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(up_btn), "clicked",
 			 G_CALLBACK(prefs_template_up_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), up_btn,
-			_("Move the selected template up"), NULL);
+	CLAWS_SET_TIP(up_btn,
+			_("Move the selected template up"));
 
 	down_btn = gtk_button_new_from_stock(GTK_STOCK_GO_DOWN);
 	gtk_widget_show (down_btn);
 	gtk_box_pack_start(GTK_BOX (vbox3), down_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT (down_btn), "clicked",
 			 G_CALLBACK(prefs_template_down_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), down_btn,
-			_("Move the selected template down"), NULL);
+	CLAWS_SET_TIP(down_btn,
+			_("Move the selected template down"));
 
 	PACK_VSPACER(vbox3, spc_vbox, VSPACING_NARROW_2);
 
@@ -390,8 +389,8 @@ static void prefs_template_window_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox3), bottom_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(bottom_btn), "clicked",
 			 G_CALLBACK(prefs_template_bottom_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), bottom_btn,
-			_("Move the selected template to the bottom"), NULL);
+	CLAWS_SET_TIP(bottom_btn,
+			_("Move the selected template to the bottom"));
 
 	list_view = prefs_template_list_view_create();
 	gtk_widget_show(list_view);
@@ -424,8 +423,6 @@ static void prefs_template_window_create(void)
 			 G_CALLBACK(manual_open_with_anchor_cb),
 			 MANUAL_ANCHOR_TEMPLATES);
 
-	address_completion_start(window);
-
 	if (!geometry.min_height) {
 		geometry.min_width = 500;
 		geometry.min_height = 540;
@@ -475,6 +472,7 @@ static void prefs_template_window_setup(void)
 	GSList *tmpl_list;
 	GSList *cur;
 	Template *tmpl;
+	int i;
 
 	manage_window_set_transient(GTK_WINDOW(templates.window));
 	gtk_widget_grab_focus(templates.ok_btn);
@@ -483,6 +481,14 @@ static void prefs_template_window_setup(void)
 	
 	tmpl_list = template_read_config();
 
+	address_completion_start(templates.window);
+
+	for (i=0; widgets_table[i].label; i++) {
+		if (widgets_table[i].compl)
+			address_completion_register_entry(
+				GTK_ENTRY(*(widgets_table[i].entry)), TRUE);
+	}
+
 	for (cur = tmpl_list; cur != NULL; cur = cur->next) {
 		tmpl = (Template *)cur->data;
 		prefs_template_list_view_insert_template(templates.list_view,
@@ -498,7 +504,7 @@ static void prefs_template_window_setup(void)
 static gint prefs_template_deleted_cb(GtkWidget *widget, GdkEventAny *event,
 				      gpointer data)
 {
-	prefs_template_cancel_cb();
+	prefs_template_cancel_cb(NULL, NULL);
 	return TRUE;
 }
 
@@ -506,7 +512,7 @@ static gboolean prefs_template_key_pressed_cb(GtkWidget *widget,
 					      GdkEventKey *event, gpointer data)
 {
 	if (event && event->keyval == GDK_Escape)
-		prefs_template_cancel_cb();
+		prefs_template_cancel_cb(NULL, NULL);
 	else {
 		GtkWidget *focused = gtkut_get_focused_child(
 					GTK_CONTAINER(widget));
@@ -517,6 +523,29 @@ static gboolean prefs_template_key_pressed_cb(GtkWidget *widget,
 	return FALSE;
 }
 
+static gboolean prefs_template_search_func_cb (GtkTreeModel *model, gint column, const gchar *key, 
+						GtkTreeIter *iter, gpointer search_data) 
+{
+	gchar *store_string;
+	gint key_len;
+	gboolean retval;
+	GtkTreePath *path;
+
+	gtk_tree_model_get (model, iter, column, &store_string, -1);
+
+	if (!store_string || !key) return FALSE;
+
+	key_len = strlen (key);
+	retval = (strncmp (key, store_string, key_len) != 0);
+
+	g_free(store_string);
+	debug_print("selecting row\n");
+	path = gtk_tree_model_get_path(model, iter);
+	prefs_template_select_row(GTK_TREE_VIEW(templates.list_view), path);
+	gtk_tree_path_free(path);
+
+	return retval;
+}
 static void prefs_template_address_completion_end(void)
 {
 	gint i;
@@ -529,7 +558,7 @@ static void prefs_template_address_completion_end(void)
 	address_completion_end(templates.window);
 }
 
-static void prefs_template_ok_cb(void)
+static void prefs_template_ok_cb(gpointer action, gpointer data)
 {
 	GSList *tmpl_list;
 	GtkListStore *store;
@@ -555,7 +584,7 @@ static void prefs_template_ok_cb(void)
 	inc_unlock();
 }
 
-static void prefs_template_cancel_cb(void)
+static void prefs_template_cancel_cb(gpointer action, gpointer data)
 {
 	GtkListStore *store;
 
@@ -640,18 +669,26 @@ gboolean prefs_template_string_is_valid(gchar *string, gint *line, gboolean esca
 {
 	gboolean result = TRUE;
 	if (string && *string != '\0') {
+		gchar *tmp = NULL;
 		gchar *parsed_buf;
 		MsgInfo dummyinfo;
 		PrefsAccount *account = account_get_default();
 
+		if (escaped_string) {
+			tmp = malloc(strlen(string)+1);
+			pref_get_unescaped_pref(tmp, string);
+		} else {
+			tmp = g_strdup(string);
+		}
 		memset(&dummyinfo, 0, sizeof(MsgInfo));
-#ifdef USE_ASPELL
-		quote_fmt_init(&dummyinfo, NULL, NULL, TRUE, account, escaped_string, NULL);
+#ifdef USE_ENCHANT
+		quote_fmt_init(&dummyinfo, NULL, NULL, TRUE, account, FALSE, NULL);
 #else
-		quote_fmt_init(&dummyinfo, NULL, NULL, TRUE, account, escaped_string);
+		quote_fmt_init(&dummyinfo, NULL, NULL, TRUE, account, FALSE);
 #endif
-		quote_fmt_scan_string(string);
+		quote_fmt_scan_string(tmp);
 		quote_fmt_parse();
+		g_free(tmp);
 		parsed_buf = quote_fmt_get_buffer();
 		if (!parsed_buf) {
 			if (line)
@@ -700,7 +737,7 @@ static gboolean prefs_template_list_view_set_row(gint row)
 			g_free(value);
 		value = NULL;
 		}
-	if (!prefs_template_string_is_valid(value, &line, FALSE, FALSE)) {
+	if (!prefs_template_string_is_valid(value, &line, TRUE, FALSE)) {
 		alertpanel_error(_("Template body format error at line %d."), line);
 		g_free(value);
 		return FALSE;
@@ -745,31 +782,31 @@ static gboolean prefs_template_list_view_set_row(gint row)
 		subject = NULL;
 	}
 
-	if (!prefs_template_string_is_valid(from, NULL, FALSE, TRUE)) {
+	if (!prefs_template_string_is_valid(from, NULL, TRUE, TRUE)) {
 		alertpanel_error(_("Template From format error."));
 		g_free(from);
 		g_free(value);
 		return FALSE;
 	}
-	if (!prefs_template_string_is_valid(to, NULL, FALSE, TRUE)) {
+	if (!prefs_template_string_is_valid(to, NULL, TRUE, TRUE)) {
 		alertpanel_error(_("Template To format error."));
 		g_free(to);
 		g_free(value);
 		return FALSE;
 	}
-	if (!prefs_template_string_is_valid(cc, NULL, FALSE, TRUE)) {
+	if (!prefs_template_string_is_valid(cc, NULL, TRUE, TRUE)) {
 		alertpanel_error(_("Template Cc format error."));	
 		g_free(cc);
 		g_free(value);
 		return FALSE;
 	}
-	if (!prefs_template_string_is_valid(bcc, NULL, FALSE, TRUE)) {
+	if (!prefs_template_string_is_valid(bcc, NULL, TRUE, TRUE)) {
 		alertpanel_error(_("Template Bcc format error."));	
 		g_free(bcc);
 		g_free(value);
 		return FALSE;
 	}
-	if (!prefs_template_string_is_valid(subject, NULL, FALSE, FALSE)) {
+	if (!prefs_template_string_is_valid(subject, NULL, TRUE, FALSE)) {
 		alertpanel_error(_("Template subject format error."));	
 		g_free(subject);
 		g_free(value);
@@ -792,13 +829,13 @@ static gboolean prefs_template_list_view_set_row(gint row)
 	return TRUE;
 }
 
-static void prefs_template_register_cb(void)
+static void prefs_template_register_cb(gpointer action, gpointer data)
 {
 	modified = !prefs_template_list_view_set_row(-1);
 	modified_list = TRUE;
 }
 
-static void prefs_template_substitute_cb(void)
+static void prefs_template_substitute_cb(gpointer action, gpointer data)
 {
 	Template *tmpl;
 	gint row;
@@ -821,7 +858,7 @@ static void prefs_template_substitute_cb(void)
 	modified_list = TRUE;
 }
 
-static void prefs_template_delete_cb(void)
+static void prefs_template_delete_cb(gpointer action, gpointer data)
 {
 	Template *tmpl;
 	gint row;
@@ -850,7 +887,7 @@ static void prefs_template_delete_cb(void)
 	modified_list = TRUE;	
 }
 
-static void prefs_template_delete_all_cb(void)
+static void prefs_template_delete_all_cb(gpointer action, gpointer data)
 {
 	GtkListStore *list_store;
 
@@ -867,7 +904,7 @@ static void prefs_template_delete_all_cb(void)
 	modified_list = TRUE;
 }
 
-static void prefs_template_duplicate_cb(void)
+static void prefs_template_duplicate_cb(gpointer action, gpointer data)
 {
 	Template *tmpl;
 	gint row;
@@ -889,12 +926,12 @@ static void prefs_template_duplicate_cb(void)
 	modified_list = !prefs_template_list_view_set_row(-row-2);
 }
 
-static void prefs_template_clear_cb(void)
+static void prefs_template_clear_cb(gpointer action, gpointer data)
 {
    prefs_template_reset_dialog();
 }
 
-static void prefs_template_top_cb(void)
+static void prefs_template_top_cb(gpointer action, gpointer data)
 {
 	gint row;
 	GtkTreeIter top, sel;
@@ -915,7 +952,7 @@ static void prefs_template_top_cb(void)
 	modified_list = TRUE;
 }
 
-static void prefs_template_up_cb(void)
+static void prefs_template_up_cb(gpointer action, gpointer data)
 {
 	gint row;
 	GtkTreeIter top, sel;
@@ -936,7 +973,7 @@ static void prefs_template_up_cb(void)
 	modified_list = TRUE;
 }
 
-static void prefs_template_down_cb(void)
+static void prefs_template_down_cb(gpointer action, gpointer data)
 {
 	gint row, n_rows;
 	GtkTreeIter top, sel;
@@ -957,7 +994,7 @@ static void prefs_template_down_cb(void)
 	modified_list = TRUE;
 }
 
-static void prefs_template_bottom_cb(void)
+static void prefs_template_bottom_cb(gpointer action, gpointer data)
 {
 	gint row, n_rows;
 	GtkTreeIter top, sel;
@@ -1043,14 +1080,15 @@ static void prefs_template_list_view_insert_template(GtkWidget *list_view,
 	}
 }
 
-static GtkItemFactory *prefs_template_popup_factory = NULL;
+static GtkActionGroup *prefs_template_popup_action = NULL;
 static GtkWidget *prefs_template_popup_menu = NULL;
 
-static GtkItemFactoryEntry prefs_template_popup_entries[] =
+static GtkActionEntry prefs_template_popup_entries[] =
 {
-   {N_("/_Delete"),		NULL, prefs_template_delete_cb, 0, NULL, NULL},
-   {N_("/Delete _all"),	NULL, prefs_template_delete_all_cb, 0, NULL, NULL},
-   {N_("/D_uplicate"),	NULL, prefs_template_duplicate_cb, 0, NULL, NULL},
+	{"PrefsTemplatePopup",			NULL, "PrefsTemplatePopup" },
+	{"PrefsTemplatePopup/Delete",		NULL, N_("_Delete"), NULL, NULL, G_CALLBACK(prefs_template_delete_cb) },
+	{"PrefsTemplatePopup/DeleteAll",	NULL, N_("Delete _all"), NULL, NULL, G_CALLBACK(prefs_template_delete_all_cb) },
+	{"PrefsTemplatePopup/Duplicate",	NULL, N_("D_uplicate"), NULL, NULL, G_CALLBACK(prefs_template_duplicate_cb) },
 };
 
 static gint prefs_template_list_btn_pressed(GtkWidget *widget, GdkEventButton *event,
@@ -1076,24 +1114,27 @@ static gint prefs_template_list_btn_pressed(GtkWidget *widget, GdkEventButton *e
 		   gint row;
 
 		   if (!prefs_template_popup_menu) {
-			   gint n_entries = sizeof(prefs_template_popup_entries) /
-					   sizeof(prefs_template_popup_entries[0]);
-			   prefs_template_popup_menu = menu_create_items(prefs_template_popup_entries,
-								 n_entries, "<PrefsTemplatePopupMenu>",
-								 &prefs_template_popup_factory, list_view);
+				prefs_template_popup_action = cm_menu_create_action_group("PrefsTemplatePopup", prefs_template_popup_entries,
+					G_N_ELEMENTS(prefs_template_popup_entries), (gpointer)list_view);
+				MENUITEM_ADDUI("/Menus", "PrefsTemplatePopup", "PrefsTemplatePopup", GTK_UI_MANAGER_MENU)
+				MENUITEM_ADDUI("/Menus/PrefsTemplatePopup", "Delete", "PrefsTemplatePopup/Delete", GTK_UI_MANAGER_MENUITEM)
+				MENUITEM_ADDUI("/Menus/PrefsTemplatePopup", "DeleteAll", "PrefsTemplatePopup/DeleteAll", GTK_UI_MANAGER_MENUITEM)
+				MENUITEM_ADDUI("/Menus/PrefsTemplatePopup", "Duplicate", "PrefsTemplatePopup/Duplicate", GTK_UI_MANAGER_MENUITEM)
+				prefs_template_popup_menu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+					gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/PrefsTemplatePopup")) );
 		   }
 
 		   /* grey out some popup menu items if there is no selected row */
 		   row = gtkut_list_view_get_selected_row(GTK_WIDGET(list_view));
-		   menu_set_sensitive(prefs_template_popup_factory, "/Delete", (row > 0));
-		   menu_set_sensitive(prefs_template_popup_factory, "/Duplicate", (row > 0));
+			cm_menu_set_sensitive("PrefsTemplatePopup/Delete", (row > 0));
+			cm_menu_set_sensitive("PrefsTemplatePopup/Duplicate", (row > 0));
 
 		   /* grey out seom popup menu items if there is no row
 			  (not counting the (New) one at row 0) */
 		   non_empty = gtk_tree_model_get_iter_first(model, &iter);
 		   if (non_empty)
 			   non_empty = gtk_tree_model_iter_next(model, &iter);
-		   menu_set_sensitive(prefs_template_popup_factory, "/Delete all", non_empty);
+			cm_menu_set_sensitive("PrefsTemplatePopup/DeleteAll", non_empty);
 
 		   gtk_menu_popup(GTK_MENU(prefs_template_popup_menu), 
 					  NULL, NULL, NULL, NULL, 
@@ -1162,6 +1203,7 @@ static void prefs_template_create_list_view_columns(GtkWidget *list_view)
 			 "text", TEMPL_TEXT,
 			 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(list_view), column);		
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(list_view), prefs_template_search_func_cb , NULL, NULL);
 }
 
  /*!
