@@ -1,5 +1,5 @@
 /* Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2007 Holger Berndt <hb@claws-mail.org>,
+ * Copyright (C) 2007-2009 Holger Berndt <hb@claws-mail.org>,
  * Colin Leroy <colin@colino.net>, and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 #  include "config.h"
 #endif
 
+#include "defs.h"
+
 #include "printing.h"
 #include "image_viewer.h"
 
@@ -112,10 +114,11 @@ static GtkPrintSettings *settings   = NULL;
 static GtkPageSetup     *page_setup = NULL;
 
 /* other static functions */
-static void     printing_layout_set_text_attributes(PrintData*, GtkPrintContext *);
+static void     printing_layout_set_text_attributes(PrintData*, GtkPrintContext *, gboolean *);
 static gboolean printing_is_pango_gdk_color_equal(PangoColor*, GdkColor*); 
 static gint     printing_text_iter_get_offset_bytes(PrintData *, const GtkTextIter*);
 
+#define PAGE_MARGIN_STORAGE_UNIT GTK_UNIT_MM
 #define PREVIEW_SCALE 72
 #define PREVIEW_SHADOW_OFFSET 3
 #define PREVIEW_ZOOM_FAC 1.41
@@ -175,13 +178,58 @@ void printing_store_settings(GtkPrintSettings *new_settings)
 GtkPageSetup *printing_get_page_setup(void)
 {
   if (page_setup == NULL) {
+    gboolean read_from_file;
+    char *page_setup_filename;
+    GKeyFile *keyfile;
+    gboolean key_file_read;
+    
     page_setup = gtk_page_setup_new();
-    if (prefs_common.print_paper_type && *prefs_common.print_paper_type) {
-      GtkPaperSize *paper = gtk_paper_size_new(prefs_common.print_paper_type);
-      gtk_page_setup_set_paper_size(page_setup, paper);
-      gtk_paper_size_free(paper);
+
+    read_from_file = FALSE;
+
+#if GTK_CHECK_VERSION(2,14,0)
+    /* try reading the page setup from file */
+    page_setup_filename = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, PRINTING_PAGE_SETUP_STORAGE_FILE, NULL);
+    keyfile = g_key_file_new();
+    key_file_read = g_key_file_load_from_file(keyfile, page_setup_filename, 0, NULL);
+    g_free(page_setup_filename);
+    
+    if(key_file_read)
+      read_from_file = gtk_page_setup_load_key_file(page_setup, keyfile, NULL, NULL);
+    g_key_file_free(keyfile);
+
+    if(read_from_file) {
+      debug_print("Printing: Read page setup from key file\n");
+    }
+    else {
+      debug_print("Printing: Could not read page setup from key file\n");
+    }
+#else
+    key_file_read = FALSE;
+    keyfile = NULL;
+    page_setup_filename = NULL;
+#endif
+
+    /* if reading from file did not work, or has not been tried (GTK+ < 2.14), use prefs */
+    if(!read_from_file) {
+      /* paper size */
+      if (prefs_common.print_paper_type && *prefs_common.print_paper_type) {
+        GtkPaperSize *paper = gtk_paper_size_new(prefs_common.print_paper_type);
+        gtk_page_setup_set_paper_size(page_setup, paper);
+        gtk_paper_size_free(paper);
+      }
+      /* orientation */
+      gtk_page_setup_set_orientation(page_setup, prefs_common.print_paper_orientation);
+      /* margins */
+      if(prefs_common.print_margin_top != -1)
+        gtk_page_setup_set_top_margin(page_setup, 0.01*prefs_common.print_margin_top, PAGE_MARGIN_STORAGE_UNIT);
+      if(prefs_common.print_margin_bottom != -1)
+        gtk_page_setup_set_bottom_margin(page_setup, 0.01*prefs_common.print_margin_bottom, PAGE_MARGIN_STORAGE_UNIT);
+      if(prefs_common.print_margin_left != -1)
+        gtk_page_setup_set_left_margin(page_setup, 0.01*prefs_common.print_margin_left, PAGE_MARGIN_STORAGE_UNIT);
+      if(prefs_common.print_margin_right != -1)
+        gtk_page_setup_set_right_margin(page_setup, 0.01*prefs_common.print_margin_right, PAGE_MARGIN_STORAGE_UNIT);
     }
-    gtk_page_setup_set_orientation(page_setup, prefs_common.print_paper_orientation);
   }
   return page_setup;
 }
@@ -229,7 +277,7 @@ void printing_print_full(GtkWindow *parent, PrintRenderer *renderer, gpointer re
   if(res == GTK_PRINT_OPERATION_RESULT_ERROR) {
     GError *error = NULL;
     gtk_print_operation_get_error(op, &error);
-    debug_print("Error printing message: %s",
+    debug_print("Error printing message: %s\n",
 	    error ? error->message : "no details");
   }
   else if(res == GTK_PRINT_OPERATION_RESULT_APPLY) {
@@ -290,6 +338,9 @@ void printing_print(GtkTextView *text_view, GtkWindow *parent, gint sel_start, g
 void printing_page_setup(GtkWindow *parent)
 {
   GtkPageSetup *new_page_setup;
+  char *keyfile;
+
+  keyfile = NULL;
 
   printing_get_settings();
   printing_get_page_setup();
@@ -305,6 +356,20 @@ void printing_page_setup(GtkWindow *parent)
   prefs_common.print_paper_type = g_strdup(gtk_paper_size_get_name(
   		gtk_page_setup_get_paper_size(page_setup)));
   prefs_common.print_paper_orientation = gtk_page_setup_get_orientation(page_setup);
+  /* store 100th millimeters */
+  prefs_common.print_margin_top    = (int) (100*gtk_page_setup_get_top_margin(page_setup, PAGE_MARGIN_STORAGE_UNIT));
+  prefs_common.print_margin_bottom = (int) (100*gtk_page_setup_get_bottom_margin(page_setup, PAGE_MARGIN_STORAGE_UNIT));
+  prefs_common.print_margin_left   = (int) (100*gtk_page_setup_get_left_margin(page_setup, PAGE_MARGIN_STORAGE_UNIT));
+  prefs_common.print_margin_right  = (int) (100*gtk_page_setup_get_right_margin(page_setup, PAGE_MARGIN_STORAGE_UNIT));
+
+#if GTK_CHECK_VERSION(2,14,0)
+  /* save to file */
+    keyfile = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, PRINTING_PAGE_SETUP_STORAGE_FILE, NULL);
+    if(!gtk_page_setup_to_file(page_setup, keyfile, NULL)) {
+      debug_print("Printing: Could not store page setup in file `%s'\n", keyfile);
+    }
+    g_free(keyfile);
+#endif
 }
 
 static gboolean cb_preview(GtkPrintOperation        *operation,
@@ -324,8 +389,9 @@ static gboolean cb_preview(GtkPrintOperation        *operation,
   GtkToolItem *separator;
   static GdkGeometry geometry;
   GtkWidget *dialog = NULL;
-  GtkTooltips *toolbar_tips = gtk_tooltips_new();
   GtkWidget *statusbar = gtk_hbox_new(2, FALSE);
+  CLAWS_TIP_DECL();
+
   debug_print("Creating internal print preview\n");
 
   print_data = (PrintData*) data;
@@ -373,14 +439,25 @@ static gboolean cb_preview(GtkPrintOperation        *operation,
 	
   gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
 
+#if !(GTK_CHECK_VERSION(2,12,0))
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget), GTK_TOOLTIPS(tips),			\
+			tip, NULL);								\
+}
+#else
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(widget), tip);				\
+}
+#endif	
+
 #define TOOLBAR_ITEM(item,text,tooltip,cb,cbdata) {								\
 	item = GTK_WIDGET(gtk_tool_button_new_from_stock(text));					\
 	gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(item), FALSE);					\
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(item), TRUE);					\
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(item), -1);				\
 	g_signal_connect (G_OBJECT(item), "clicked", G_CALLBACK(cb), cbdata);				\
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(item), GTK_TOOLTIPS(toolbar_tips),			\
-			tooltip, NULL);									\
+	CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(item),		\
+			tooltip);									\
 }
 
   TOOLBAR_ITEM(preview_data->first, GTK_STOCK_GOTO_FIRST, _("First page"), cb_preview_go_first, preview_data);
@@ -480,7 +557,7 @@ static gboolean cb_preview_close(GtkWidget *widget, GdkEventAny *event,
 static void cb_preview_size_allocate(GtkWidget *widget,
 				     GtkAllocation *allocation)
 {
-  g_return_if_fail(allocation != NULL);
+  cm_return_if_fail(allocation != NULL);
 
   prefs_common.print_previewwin_width = allocation->width;
   prefs_common.print_previewwin_height = allocation->height;
@@ -763,8 +840,11 @@ static void printing_textview_cb_begin_print(GtkPrintOperation *op, GtkPrintCont
   int start, ii;
   PangoLayoutIter *iter;
   double start_pos;
+  gint header_end_pos;
   gint num_header_lines;
+  gint dummy;
   gboolean header_done;
+  gboolean has_headers = FALSE;
   const gchar *text;
   double line_height =0.;
 
@@ -790,7 +870,7 @@ static void printing_textview_cb_begin_print(GtkPrintOperation *op, GtkPrintCont
   pango_layout_set_width(print_data->layout, width * PANGO_SCALE);
   pango_layout_set_text(print_data->layout, (char *)print_data->to_print, -1);
 
-  printing_layout_set_text_attributes(print_data, context);
+  printing_layout_set_text_attributes(print_data, context, &has_headers);
 
   num_lines = pango_layout_get_line_count(print_data->layout);
 
@@ -801,20 +881,28 @@ static void printing_textview_cb_begin_print(GtkPrintOperation *op, GtkPrintCont
   start_pos = 0.;
   iter = pango_layout_get_iter(print_data->layout);
 
-  /* count number of header lines */
-  num_header_lines = 0;
+  /* find the last character of the header */
+  header_end_pos = 0;
   header_done = FALSE;
   text = pango_layout_get_text(print_data->layout);
-  if(text && *text && *text != '\n') {
-    do {
-      if(text[0] == '\n' && (text[1] != '\0')) {
-	num_header_lines++;
-	if(text[1] == '\n') {
+  
+  if (has_headers) {
+    if(text && *text && *text != '\n') {
+      do {
+	if(text[0] == '\n' && (text[1] != '\0') && (text[1] == '\n'))
 	  header_done = TRUE;
-	}
-      }
-      text++;
-    } while(*text && !header_done);
+	else
+	  header_end_pos++;
+	text++;
+      } while(*text && !header_done);
+    }
+    /* find line number for header end */
+    pango_layout_index_to_line_x(print_data->layout, header_end_pos, 1,
+				 &num_header_lines, &dummy);
+    /* line count is zero-based */
+    num_header_lines++;
+  } else {
+    print_data->ypos_line = -1.0;
   }
 
   do {
@@ -840,7 +928,7 @@ static void printing_textview_cb_begin_print(GtkPrintOperation *op, GtkPrintCont
       page_height = 0;
     }
 
-    if(ii == num_header_lines) {
+    if(has_headers && ii == num_header_lines) {
       int y0, y1;
       pango_layout_iter_get_line_yrange(iter,&y0,&y1);
       print_data->ypos_line = (double)y0 + 1./3.*((double)(y1 - y0))/2.;
@@ -987,7 +1075,7 @@ static void printing_textview_cb_draw_page(GtkPrintOperation *op, GtkPrintContex
 	start_pos = ((double)logical_rect.y) / PANGO_SCALE;
 
       /* Draw header separator line */
-      if(ii == 0) {
+      if(ii == 0 && print_data->ypos_line >= 0) {
 	cairo_surface_t *surface;
 	surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
 					     gtk_print_context_get_width(context)/print_data->zoom,
@@ -1028,7 +1116,7 @@ static void printing_textview_cb_draw_page(GtkPrintOperation *op, GtkPrintContex
   debug_print("Sent page %d to printer\n", page_nr+1);
 }
 
-static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintContext *context)
+static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintContext *context, gboolean *has_headers)
 {
   GtkTextIter iter;
   PangoAttrList *attr_list;
@@ -1037,6 +1125,9 @@ static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintC
   GtkTextView *text_view = GTK_TEXT_VIEW(print_data->renderer_data);
   GtkTextBuffer *buffer = gtk_text_view_get_buffer(text_view);
 
+
+  *has_headers = FALSE;
+
   attr_list = pango_attr_list_new();
   if (print_data->sel_start < 0 || print_data->sel_end <= print_data->sel_start) {
     gtk_text_buffer_get_start_iter(buffer, &iter);
@@ -1049,7 +1140,7 @@ static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintC
     gboolean fg_set, bg_set, under_set, strike_set, weight_set;
     GSList *tags, *tag_walk;
     GtkTextTag *tag;
-    GdkColor *color;
+    GdkColor *color = NULL;
     PangoUnderline underline;
     gboolean strikethrough;
     gint weight;
@@ -1104,7 +1195,7 @@ static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintC
 	    if(attr->klass->type == PANGO_ATTR_FOREGROUND) {
 	      attr_color = (PangoAttrColor*) attr;
 	      g_object_get(G_OBJECT(tag), "foreground_gdk", &color, NULL);
-	      if(printing_is_pango_gdk_color_equal(&(attr_color->color), color)) {
+	      if(color && printing_is_pango_gdk_color_equal(&(attr_color->color), color)) {
 		attr->end_index = printing_text_iter_get_offset_bytes(print_data, &iter);
 		pango_attr_list_insert(attr_list, attr);
 		found = TRUE;
@@ -1218,6 +1309,7 @@ static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintC
 		     "foreground-set", &fg_set,
 		     "underline-set", &under_set,
 		     "strikethrough-set", &strike_set,
+		     "weight-set", &weight_set,
 		     NULL);
 	if(fg_set) {
 	  g_object_get(G_OBJECT(tag), "foreground-gdk", &color, NULL);
@@ -1249,6 +1341,10 @@ static void printing_layout_set_text_attributes(PrintData *print_data, GtkPrintC
 		attr = pango_attr_weight_new(weight);
 		attr->start_index = printing_text_iter_get_offset_bytes(print_data, &iter);
 		open_attrs = g_slist_prepend(open_attrs, attr); 
+		/* Hack to see if the first char is bold -- indicates header */
+		if (attr->start_index == 0 && weight == PANGO_WEIGHT_BOLD) {
+			*has_headers = TRUE;
+		}
 	}
       }
       g_slist_free(tags);
