@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2008 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -112,10 +112,10 @@ static void subject_relation_insert(GRelation *relation, GNode *node)
 	gchar *subject;
 	MsgInfo *msginfo;
 
-	g_return_if_fail(relation != NULL);
-	g_return_if_fail(node != NULL);
+	cm_return_if_fail(relation != NULL);
+	cm_return_if_fail(node != NULL);
 	msginfo = (MsgInfo *) node->data;
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(msginfo != NULL);
 
 	subject = msginfo->subject;
 	if (subject == NULL)
@@ -132,7 +132,7 @@ static GNode *subject_relation_lookup(GRelation *relation, MsgInfo *msginfo)
 	GNode *node = NULL;
 	gint prefix_length;
     
-	g_return_val_if_fail(relation != NULL, NULL);
+	cm_return_val_if_fail(relation != NULL, NULL);
 
 	subject = msginfo->subject;
 	if (subject == NULL)
@@ -383,7 +383,7 @@ gchar *procmsg_get_message_file_path(MsgInfo *msginfo)
 {
 	gchar *file;
 
-	g_return_val_if_fail(msginfo != NULL, NULL);
+	cm_return_val_if_fail(msginfo != NULL, NULL);
 
 	if (msginfo->plaintext_file)
 		file = g_strdup(msginfo->plaintext_file);
@@ -398,7 +398,7 @@ gchar *procmsg_get_message_file(MsgInfo *msginfo)
 {
 	gchar *filename = NULL;
 
-	g_return_val_if_fail(msginfo != NULL, NULL);
+	cm_return_val_if_fail(msginfo != NULL, NULL);
 
 	filename = folder_item_fetch_msg(msginfo->folder, msginfo->msgnum);
 	if (!filename)
@@ -411,7 +411,7 @@ gchar *procmsg_get_message_file_full(MsgInfo *msginfo, gboolean headers, gboolea
 {
 	gchar *filename = NULL;
 
-	g_return_val_if_fail(msginfo != NULL, NULL);
+	cm_return_val_if_fail(msginfo != NULL, NULL);
 
 	filename = folder_item_fetch_msg_full(msginfo->folder, msginfo->msgnum,
 						headers, body);
@@ -470,10 +470,10 @@ FILE *procmsg_open_message(MsgInfo *msginfo)
 	FILE *fp;
 	gchar *file;
 
-	g_return_val_if_fail(msginfo != NULL, NULL);
-
+	cm_return_val_if_fail(msginfo != NULL, NULL);
+	
 	file = procmsg_get_message_file_path(msginfo);
-	g_return_val_if_fail(file != NULL, NULL);
+	cm_return_val_if_fail(file != NULL, NULL);
 
 	if (!is_file_exist(file)) {
 		g_free(file);
@@ -557,9 +557,9 @@ void procmsg_get_filter_keyword(MsgInfo *msginfo, gchar **header, gchar **key,
 
 	FILE *fp;
 
-	g_return_if_fail(msginfo != NULL);
-	g_return_if_fail(header != NULL);
-	g_return_if_fail(key != NULL);
+	cm_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(header != NULL);
+	cm_return_if_fail(key != NULL);
 
 	*header = NULL;
 	*key = NULL;
@@ -580,7 +580,10 @@ void procmsg_get_filter_keyword(MsgInfo *msginfo, gchar **header, gchar **key,
 	hentry[idx].body = NULL;	\
 }
 
-		if (hentry[H_X_BEENTHERE].body != NULL) {
+		if (hentry[H_LIST_ID].body != NULL) {
+			SET_FILTER_KEY("header \"List-Id\"", H_LIST_ID);
+			extract_list_id_str(*key);
+		} else if (hentry[H_X_BEENTHERE].body != NULL) {
 			SET_FILTER_KEY("header \"X-BeenThere\"", H_X_BEENTHERE);
 		} else if (hentry[H_X_ML_NAME].body != NULL) {
 			SET_FILTER_KEY("header \"X-ML-Name\"", H_X_ML_NAME);
@@ -588,10 +591,7 @@ void procmsg_get_filter_keyword(MsgInfo *msginfo, gchar **header, gchar **key,
 			SET_FILTER_KEY("header \"X-List\"", H_X_LIST);
 		} else if (hentry[H_X_MAILING_LIST].body != NULL) {
 			SET_FILTER_KEY("header \"X-Mailing-List\"", H_X_MAILING_LIST);
-		} else if (hentry[H_LIST_ID].body != NULL) {
-			SET_FILTER_KEY("header \"List-Id\"", H_LIST_ID);
-			extract_list_id_str(*key);
-		} else if (hentry[H_X_SEQUENCE].body != NULL) {
+		} else  if (hentry[H_X_SEQUENCE].body != NULL) {
 			gchar *p;
 
 			SET_FILTER_KEY("X-Sequence", H_X_SEQUENCE);
@@ -731,7 +731,7 @@ static PrefsAccount *procmsg_get_account_from_file(const gchar *file)
 				       {"X-Sylpheed-Encrypt-Data:", NULL, FALSE},
 				       {NULL,    NULL, FALSE}};
 	
-	g_return_val_if_fail(file != NULL, NULL);
+	cm_return_val_if_fail(file != NULL, NULL);
 
 	if ((fp = g_fopen(file, "rb")) == NULL) {
 		FILE_OP_ERROR(file, "fopen");
@@ -957,7 +957,7 @@ gboolean procmsg_queue_is_empty(FolderItem *queue)
 	gboolean res = FALSE;
 	if (!queue)
 		queue = folder_get_default_queue();
-	g_return_val_if_fail(queue != NULL, TRUE);
+	cm_return_val_if_fail(queue != NULL, TRUE);
 
 	folder_item_scan(queue);
 	list = folder_item_get_msg_list(queue);
@@ -1029,7 +1029,7 @@ static gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file,
 
 	if (!outbox)
 		outbox = folder_get_default_outbox();
-	g_return_val_if_fail(outbox != NULL, -1);
+	cm_return_val_if_fail(outbox != NULL, -1);
 
 	/* remove queueing headers */
 	if (is_queued) {
@@ -1044,7 +1044,7 @@ static gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file,
 		folder_item_scan(outbox);
 		if ((num = folder_item_add_msg(outbox, tmp, &flag, TRUE)) < 0) {
 			g_warning("can't save message\n");
-			g_unlink(tmp);
+			claws_unlink(tmp);
 			return -1;
 		}
 	} else {
@@ -1081,7 +1081,7 @@ void procmsg_print_message(MsgInfo *msginfo, const gchar *cmdline)
 	gchar buf[1024];
 	gchar *p;
 	int r;
-	g_return_if_fail(msginfo);
+	cm_return_if_fail(msginfo);
 
 	if (procmime_msginfo_is_encrypted(msginfo))
 		tmpfp = procmime_get_first_encrypted_text_content(msginfo);
@@ -1122,7 +1122,7 @@ void procmsg_print_message(MsgInfo *msginfo, const gchar *cmdline)
 		g_snprintf(buf, sizeof(buf) - 1, cmdline, prtmp);
 	else {
 		if (cmdline)
-			g_warning("Print command line is invalid: '%s'\n",
+			g_warning("Print command-line is invalid: '%s'\n",
 				  cmdline);
 		g_snprintf(buf, sizeof(buf) - 1, def_cmd, prtmp);
 	}
@@ -1460,7 +1460,7 @@ static gint procmsg_send_message_queue_full(const gchar *file, gboolean keep_ses
 
 	int local = 0;
 
-	g_return_val_if_fail(file != NULL, -1);
+	cm_return_val_if_fail(file != NULL, -1);
 
 	if ((fp = g_fopen(file, "rb")) == NULL) {
 		FILE_OP_ERROR(file, "fopen");
@@ -1647,7 +1647,7 @@ send_mail:
 	}
 
 	fseek(fp, filepos, SEEK_SET);
-	if (newsgroup_list && (mailval == 0)) {
+	if (newsgroup_list && newsac && (mailval == 0)) {
 		Folder *folder;
 		gchar *tmp = NULL;
 		FILE *tmpfp;
@@ -1689,7 +1689,7 @@ send_mail:
                             		 newsac->nntp_server);
 				}
 			}
-			g_unlink(tmp);
+			claws_unlink(tmp);
 		}
 		g_free(tmp);
 	}
@@ -1732,7 +1732,7 @@ send_mail:
 	}
 
 	if (tmp_enc_file != NULL) {
-		g_unlink(tmp_enc_file);
+		claws_unlink(tmp_enc_file);
 		free(tmp_enc_file);
 		tmp_enc_file = NULL;
 	}
@@ -1891,9 +1891,9 @@ void procmsg_msginfo_set_flags(MsgInfo *msginfo, MsgPermFlags perm_flags, MsgTmp
 	MsgPermFlags perm_flags_new, perm_flags_old;
 	MsgTmpFlags tmp_flags_old;
 
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(msginfo != NULL);
 	item = msginfo->folder;
-	g_return_if_fail(item != NULL);
+	cm_return_if_fail(item != NULL);
 	
 	debug_print("Setting flags for message %d in folder %s\n", msginfo->msgnum, item->path);
 
@@ -1934,9 +1934,9 @@ void procmsg_msginfo_unset_flags(MsgInfo *msginfo, MsgPermFlags perm_flags, MsgT
 	MsgPermFlags perm_flags_new, perm_flags_old;
 	MsgTmpFlags tmp_flags_old;
 
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(msginfo != NULL);
 	item = msginfo->folder;
-	g_return_if_fail(item != NULL);
+	cm_return_if_fail(item != NULL);
 	
 	debug_print("Unsetting flags for message %d in folder %s\n", msginfo->msgnum, item->path);
 
@@ -1972,9 +1972,9 @@ void procmsg_msginfo_change_flags(MsgInfo *msginfo,
 	MsgPermFlags perm_flags_new, perm_flags_old;
 	MsgTmpFlags tmp_flags_old;
 
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(msginfo != NULL);
 	item = msginfo->folder;
-	g_return_if_fail(item != NULL);
+	cm_return_if_fail(item != NULL);
 	
 	debug_print("Changing flags for message %d in folder %s\n", msginfo->msgnum, item->path);
 
@@ -2023,7 +2023,7 @@ static gboolean procmsg_msg_has_flagged_parent_real(MsgInfo *info,
 {
 	MsgInfo *tmp;
 
-	g_return_val_if_fail(info != NULL, FALSE);
+	cm_return_val_if_fail(info != NULL, FALSE);
 
 	if (info != NULL && info->folder != NULL && info->inreplyto != NULL) {
 		tmp = folder_item_get_msginfo_by_msgid(info->folder,
@@ -2095,7 +2095,7 @@ static GSList *procmsg_find_children_func(MsgInfo *info,
 {
 	GSList *cur;
 
-	g_return_val_if_fail(info!=NULL, children);
+	cm_return_val_if_fail(info!=NULL, children);
 	if (info->msgid == NULL)
 		return children;
 
@@ -2121,7 +2121,7 @@ static GSList *procmsg_find_children (MsgInfo *info)
 	GSList *children;
 	GSList *all, *cur;
 
-	g_return_val_if_fail(info!=NULL, NULL);
+	cm_return_val_if_fail(info!=NULL, NULL);
 	all = folder_item_get_msg_list(info->folder);
 	children = procmsg_find_children_func(info, NULL, all);
 	if (children != NULL) {
@@ -2212,8 +2212,8 @@ void procmsg_msglist_filter(GSList *list, PrefsAccount *ac,
 	gint total = 0, curnum = 0;
 	MailFilteringData mail_filtering_data;
 			
-	g_return_if_fail(filtered != NULL);
-	g_return_if_fail(unfiltered != NULL);
+	cm_return_if_fail(filtered != NULL);
+	cm_return_if_fail(unfiltered != NULL);
 
 	*filtered = NULL;
 	*unfiltered = NULL;
