@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 2001-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,9 +91,9 @@ static void activate_compose_button 		(Toolbar	*toolbar,
 
 /* toolbar callbacks */
 static void toolbar_reply			(gpointer 	 data, 
-						 guint 		 action);
+						 guint		 action);
 static void toolbar_learn			(gpointer 	 data, 
-						 guint 		 action);
+						 guint		 action);
 static void toolbar_delete_cb			(GtkWidget	*widget,
 					 	 gpointer        data);
 static void toolbar_trash_cb			(GtkWidget	*widget,
@@ -146,6 +146,8 @@ static void toolbar_draft_cb			(GtkWidget	*widget,
 					 	 gpointer	 data);
 static void toolbar_close_cb			(GtkWidget	*widget,
 					 	 gpointer	 data);
+static void toolbar_preferences_cb		(GtkWidget	*widget,
+					 	 gpointer	 data);
 static void toolbar_open_mail_cb		(GtkWidget	*widget,
 						 gpointer	 data);
 static void toolbar_insert_cb			(GtkWidget	*widget,
@@ -162,7 +164,7 @@ static void toolbar_linewrap_all_cb		(GtkWidget	*widget,
 					 	 gpointer	 data);
 static void toolbar_addrbook_cb   		(GtkWidget   	*widget, 
 					 	 gpointer     	 data);
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 static void toolbar_check_spelling_cb  		(GtkWidget   	*widget, 
 					 	 gpointer     	 data);
 #endif
@@ -194,6 +196,7 @@ struct {
 	{ "A_PRINT",	     	N_("Print")				   },
 	{ "A_LEARN_SPAM",	N_("Learn Spam or Ham")			   },
 	{ "A_GO_FOLDERS",   	N_("Open folder/Go to folder list")        },
+	{ "A_PREFERENCES",	N_("Preferences")			   },
 
 	{ "A_SEND",          	N_("Send Message")                         },
 	{ "A_SENDL",         	N_("Put into queue folder and send later") },
@@ -205,7 +208,7 @@ struct {
 	{ "A_LINEWRAP_CURRENT",	N_("Wrap long lines of current paragraph") }, 
 	{ "A_LINEWRAP_ALL",     N_("Wrap all long lines")                  }, 
 	{ "A_ADDRBOOK",      	N_("Address book")                         },
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	{ "A_CHECK_SPELLING",	N_("Check spelling")                       },
 #endif
 	{ "A_CLAWS_ACTIONS",   	N_("Claws Mail Actions Feature")	   }, 
@@ -227,40 +230,6 @@ struct {
 	{ "toolbar_compose.xml", NULL}, 
   	{ "toolbar_msgview.xml", NULL}
 };
-#ifndef MAEMO
-static GtkItemFactoryEntry reply_entries[] =
-{
-	{N_("/Reply with _quote"), NULL,    toolbar_reply, COMPOSE_REPLY_WITH_QUOTE, NULL},
-	{N_("/_Reply without quote"), NULL, toolbar_reply, COMPOSE_REPLY_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replyall_entries[] =
-{
-	{N_("/Reply to all with _quote"), "<shift>A", toolbar_reply, COMPOSE_REPLY_TO_ALL_WITH_QUOTE, NULL},
-	{N_("/_Reply to all without quote"), "a",     toolbar_reply, COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replylist_entries[] =
-{
-	{N_("/Reply to list with _quote"),    NULL, toolbar_reply, COMPOSE_REPLY_TO_LIST_WITH_QUOTE, NULL},
-	{N_("/_Reply to list without quote"), NULL, toolbar_reply, COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replysender_entries[] =
-{
-	{N_("/Reply to sender with _quote"),    NULL, toolbar_reply, COMPOSE_REPLY_TO_SENDER_WITH_QUOTE, NULL},
-	{N_("/_Reply to sender without quote"), NULL, toolbar_reply, COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry forward_entries[] =
-{
-	{N_("/_Forward"),		"f", 	    toolbar_reply, COMPOSE_FORWARD_INLINE, NULL},
-	{N_("/For_ward as attachment"), "<shift>F", toolbar_reply, COMPOSE_FORWARD_AS_ATTACH, NULL},
-	{N_("/Redirec_t"),		NULL, 	    toolbar_reply, COMPOSE_REDIRECT, NULL}
-};
-#endif
-static GtkItemFactoryEntry learn_entries[] =
-{
-	{N_("/Learn as _Spam"),		NULL,	toolbar_learn, TRUE, NULL},
-	{N_("/Learn as _Ham"), 		NULL,	toolbar_learn, FALSE, NULL}
-};
-
 
 gint toolbar_ret_val_from_descr(const gchar *descr)
 {
@@ -276,7 +245,7 @@ gint toolbar_ret_val_from_descr(const gchar *descr)
 
 gchar *toolbar_ret_descr_from_val(gint val)
 {
-	g_return_val_if_fail(val >=0 && val < N_ACTION_VAL, NULL);
+	cm_return_val_if_fail(val >=0 && val < N_ACTION_VAL, NULL);
 
 	return gettext(toolbar_text[val].descr);
 }
@@ -295,7 +264,7 @@ static gint toolbar_ret_val_from_text(const gchar *text)
 
 static gchar *toolbar_ret_text_from_val(gint val)
 {
-	g_return_val_if_fail(val >=0 && val < N_ACTION_VAL, NULL);
+	cm_return_val_if_fail(val >=0 && val < N_ACTION_VAL, NULL);
 
 	return toolbar_text[val].index_str;
 }
@@ -332,7 +301,7 @@ GList *toolbar_get_action_items(ToolbarType source)
 					A_TRASH , A_DELETE_REAL,       A_EXECUTE,       A_GOTO_PREV, 
 					A_GOTO_NEXT,	A_IGNORE_THREAD,  A_WATCH_THREAD,	A_PRINT,
 					A_ADDRBOOK, 	A_LEARN_SPAM, A_GO_FOLDERS, 
-					A_CANCEL_INC };
+					A_CANCEL_INC,   A_PREFERENCES };
 
 		for (i = 0; i < sizeof main_items / sizeof main_items[0]; i++)  {
 			items = g_list_append(items, gettext(toolbar_text[main_items[i]].descr));
@@ -343,7 +312,7 @@ GList *toolbar_get_action_items(ToolbarType source)
 					A_INSERT,        A_ATTACH,       A_SIG,
 					A_EXTEDITOR,     A_LINEWRAP_CURRENT,     
 					A_LINEWRAP_ALL,  A_ADDRBOOK,
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 					A_CHECK_SPELLING, 
 #endif
 					A_CLOSE };	
@@ -433,6 +402,7 @@ const gchar *toolbar_get_short_text(int action) {
 	case A_WATCH_THREAD: 	return _("Watch thread");
 	case A_PRINT:	 	return _("Print");
 	case A_CLOSE: 		return _("Close");
+	case A_PREFERENCES:	return _("Preferences");
 	case A_SEND: 		return _("Send");
 	case A_SENDL: 		return _("Send later");
 	case A_DRAFT: 		return _("Draft");
@@ -445,7 +415,7 @@ const gchar *toolbar_get_short_text(int action) {
 	case A_ADDRBOOK: 	return _("Address");
 	case A_CANCEL_INC:	return _("Stop");
 	case A_EXECUTE:		return _("Execute");
-	#ifdef USE_ASPELL
+	#ifdef USE_ENCHANT
 	case A_CHECK_SPELLING:	return _("Check spelling");
 	#endif
 	default:		return "";
@@ -464,10 +434,10 @@ gint toolbar_get_icon(int action) {
 	case A_REPLY_MESSAGE: 	return STOCK_PIXMAP_MAIL_REPLY;
 	case A_REPLY_ALL: 	return STOCK_PIXMAP_MAIL_REPLY_TO_ALL;
 	case A_REPLY_SENDER: 	return STOCK_PIXMAP_MAIL_REPLY_TO_AUTHOR;
-	case A_REPLY_ML: 	return STOCK_PIXMAP_MAIL_REPLY;
+	case A_REPLY_ML: 	return STOCK_PIXMAP_MAIL_REPLY_TO_LIST;
 	case A_FORWARD: 	return STOCK_PIXMAP_MAIL_FORWARD;
 	case A_TRASH: 		return STOCK_PIXMAP_TRASH;
-	case A_DELETE_REAL:	return STOCK_PIXMAP_DELETED;
+	case A_DELETE_REAL:	return STOCK_PIXMAP_DELETE;
 	case A_LEARN_SPAM: 	return STOCK_PIXMAP_SPAM_BTN;
 	case A_GOTO_PREV: 	return STOCK_PIXMAP_UP_ARROW;
 	case A_GOTO_NEXT: 	return STOCK_PIXMAP_DOWN_ARROW;
@@ -475,6 +445,7 @@ gint toolbar_get_icon(int action) {
 	case A_WATCH_THREAD: 	return STOCK_PIXMAP_WATCHTHREAD;
 	case A_PRINT:	 	return STOCK_PIXMAP_PRINTER;
 	case A_CLOSE: 		return STOCK_PIXMAP_CLOSE;
+	case A_PREFERENCES:	return STOCK_PIXMAP_PREFERENCES;
 	case A_SEND: 		return STOCK_PIXMAP_MAIL_SEND;
 	case A_SENDL: 		return STOCK_PIXMAP_MAIL_SEND_QUEUE;
 	case A_DRAFT: 		return STOCK_PIXMAP_MAIL;
@@ -485,9 +456,9 @@ gint toolbar_get_icon(int action) {
 	case A_LINEWRAP_CURRENT:return STOCK_PIXMAP_LINEWRAP_CURRENT;
 	case A_LINEWRAP_ALL:	return STOCK_PIXMAP_LINEWRAP_ALL;
 	case A_ADDRBOOK: 	return STOCK_PIXMAP_ADDRESS_BOOK;
-	case A_CANCEL_INC:	return STOCK_PIXMAP_NOTICE_ERROR;
+	case A_CANCEL_INC:	return STOCK_PIXMAP_CANCEL;
 	case A_EXECUTE:		return STOCK_PIXMAP_EXEC;
-	#ifdef USE_ASPELL
+	#ifdef USE_ENCHANT
 	case A_CHECK_SPELLING:	return STOCK_PIXMAP_CHECK_SPELLING;
 	#endif
 	default:		return -1;
@@ -499,7 +470,7 @@ static void toolbar_set_default_main(void)
 	struct {
 		gint action;
 	} default_toolbar[] = {
-#ifdef MAEMO
+#ifdef GENERIC_UMPC
 		{ A_GO_FOLDERS},
 		{ A_OPEN_MAIL},		
 		{ A_SEPARATOR}, 
@@ -510,14 +481,14 @@ static void toolbar_set_default_main(void)
 		{ A_COMPOSE_EMAIL},
 		{ A_SEPARATOR},
 		{ A_REPLY_MESSAGE}, 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 		{ A_REPLY_ALL},
 		{ A_REPLY_SENDER},
 #endif
 		{ A_FORWARD},
 		{ A_SEPARATOR},
 		{ A_TRASH},
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 #if (defined(USE_SPAMASSASSIN_PLUGIN) || defined(USE_BOGOFILTER_PLUGIN))
 		{ A_LEARN_SPAM},
 #endif
@@ -534,7 +505,10 @@ static void toolbar_set_default_main(void)
 		
 		if (default_toolbar[i].action != A_SEPARATOR) {
 			
-			gchar *file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
+			gchar *file = NULL;
+			if (toolbar_get_icon(default_toolbar[i].action) > -1) {
+				file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
+			}
 			
 			toolbar_item->file  = g_strdup(file);
 			toolbar_item->index = default_toolbar[i].action;
@@ -558,7 +532,7 @@ static void toolbar_set_default_compose(void)
 	struct {
 		gint action;
 	} default_toolbar[] = {
-#ifdef MAEMO
+#ifdef GENERIC_UMPC
 		{ A_CLOSE},
 		{ A_SEPARATOR}, 
 #endif
@@ -566,7 +540,7 @@ static void toolbar_set_default_compose(void)
 		{ A_SENDL},
 		{ A_DRAFT},
 		{ A_SEPARATOR}, 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 		{ A_INSERT},
 #endif
 		{ A_ATTACH},
@@ -582,8 +556,10 @@ static void toolbar_set_default_compose(void)
 		
 		if (default_toolbar[i].action != A_SEPARATOR) {
 			
-			gchar *file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
-			
+			gchar *file = NULL;
+			if (toolbar_get_icon(default_toolbar[i].action) > -1) {
+				file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
+			}
 			toolbar_item->file  = g_strdup(file);
 			toolbar_item->index = default_toolbar[i].action;
 			toolbar_item->text  = g_strdup(toolbar_get_short_text(default_toolbar[i].action));
@@ -606,7 +582,7 @@ static void toolbar_set_default_msgview(void)
 	struct {
 		gint action;
 	} default_toolbar[] = {
-#ifdef MAEMO
+#ifdef GENERIC_UMPC
 		{ A_CLOSE},
 		{ A_SEPARATOR}, 
 #endif
@@ -616,7 +592,7 @@ static void toolbar_set_default_msgview(void)
 		{ A_FORWARD},
 		{ A_SEPARATOR},
 		{ A_TRASH},
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 #if (defined(USE_SPAMASSASSIN_PLUGIN) || defined(USE_BOGOFILTER_PLUGIN))
 		{ A_LEARN_SPAM},
 #endif
@@ -631,8 +607,10 @@ static void toolbar_set_default_msgview(void)
 		ToolbarItem *toolbar_item = g_new0(ToolbarItem, 1);
 		
 		if (default_toolbar[i].action != A_SEPARATOR) {
-			
-			gchar *file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
+			gchar *file = NULL;
+			if (toolbar_get_icon(default_toolbar[i].action) > -1) {
+				file = stock_pixmap_get_name((StockPixmap)toolbar_get_icon(default_toolbar[i].action));
+			}
 			
 			toolbar_item->file  = g_strdup(file);
 			toolbar_item->index = default_toolbar[i].action;
@@ -869,10 +847,35 @@ static void toolbar_action_execute(GtkWidget    *widget,
 		g_warning ("Error: did not find Claws Action to execute");
 }
 
+#if !(GTK_CHECK_VERSION(2,12,0))
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget), GTK_TOOLTIPS(toolbar_tips),	\
+			tip, NULL);								\
+}
+#else
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(widget), tip);				\
+}
+#endif	
+
+#if !(GTK_CHECK_VERSION(2,12,0))
+#define CLAWS_SET_ARROW_TIP(widget,tip) { \
+	gtk_menu_tool_button_set_arrow_tooltip(GTK_MENU_TOOL_BUTTON(widget), GTK_TOOLTIPS(toolbar_tips),	\
+			tip, NULL);								\
+}
+#else
+#define CLAWS_SET_ARROW_TIP(widget,tip) { \
+	gtk_menu_tool_button_set_arrow_tooltip_text(GTK_MENU_TOOL_BUTTON(widget), tip);				\
+}
+#endif	
+
 static void activate_compose_button (Toolbar           *toolbar,
 				     ToolbarStyle      style,
 				     ComposeButtonType type)
 {
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = toolbar->tooltips;
+#endif
 	if ((!toolbar->compose_mail_btn))
 		return;
 
@@ -880,18 +883,16 @@ static void activate_compose_button (Toolbar           *toolbar,
 		gtk_tool_button_set_icon_widget(
 			GTK_TOOL_BUTTON(toolbar->compose_mail_btn),
 			toolbar->compose_news_icon);
-#ifndef MAEMO
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->compose_mail_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Compose News message"), NULL);
+#ifndef GENERIC_UMPC
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->compose_mail_btn), _("Compose News message"));
 #endif	
 		gtk_widget_show(toolbar->compose_news_icon);
 	} else {
 		gtk_tool_button_set_icon_widget(
 			GTK_TOOL_BUTTON(toolbar->compose_mail_btn),
 			toolbar->compose_mail_icon);
-#ifndef MAEMO
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->compose_mail_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Compose Email"), NULL);
+#ifndef GENERIC_UMPC
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->compose_mail_btn), _("Compose Email"));
 #endif	
 		gtk_widget_show(toolbar->compose_mail_icon);
 	}
@@ -911,6 +912,9 @@ static void activate_learn_button (Toolbar           *toolbar,
 				     ToolbarStyle      style,
 				     LearnButtonType type)
 {
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = toolbar->tooltips;
+#endif
 	if ((!toolbar->learn_spam_btn))
 		return;
 
@@ -921,9 +925,8 @@ static void activate_learn_button (Toolbar           *toolbar,
 		gtk_tool_button_set_label(
 			GTK_TOOL_BUTTON(toolbar->learn_spam_btn),
 			_("Spam"));
-#ifndef MAEMO
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->learn_spam_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Learn spam"), NULL);	
+#ifndef GENERIC_UMPC
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->learn_spam_btn), _("Learn spam"));	
 #endif
 		gtk_widget_show(toolbar->learn_spam_icon);
 	} else {
@@ -933,9 +936,8 @@ static void activate_learn_button (Toolbar           *toolbar,
 		gtk_tool_button_set_label(
 			GTK_TOOL_BUTTON(toolbar->learn_spam_btn),
 			_("Ham"));
-#ifndef MAEMO
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->learn_spam_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Learn ham"), NULL);
+#ifndef GENERIC_UMPC
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->learn_spam_btn), _("Learn ham"));
 #endif	
 		gtk_widget_show(toolbar->learn_ham_icon);
 	}
@@ -957,7 +959,7 @@ void toolbar_toggle(guint action, gpointer data)
 	GList *list;
 	GList *cur;
 
-	g_return_if_fail(mainwin != NULL);
+	cm_return_if_fail(mainwin != NULL);
 
 	toolbar_style(TOOLBAR_MAIN, action, mainwin);
 
@@ -1017,7 +1019,7 @@ static void toolbar_style(ToolbarType type, guint action, gpointer data)
 	Compose    *compose = (Compose*)data;
 	MessageView *msgview = (MessageView*)data;
 	
-	g_return_if_fail(data != NULL);
+	cm_return_if_fail(data != NULL);
 	
 	switch (type) {
 	case TOOLBAR_MAIN:
@@ -1046,7 +1048,7 @@ static void toolbar_inc_cb(GtkWidget	*widget,
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1064,7 +1066,7 @@ static void toolbar_inc_all_cb(GtkWidget	*widget,
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1081,7 +1083,7 @@ static void toolbar_send_queued_cb(GtkWidget *widget,gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1098,7 +1100,7 @@ static void toolbar_exec_cb(GtkWidget	*widget,
 {
 	MainWindow *mainwin = get_mainwin(data);
 
-	g_return_if_fail(mainwin != NULL);
+	cm_return_if_fail(mainwin != NULL);
 	summary_execute(mainwin->summaryview);
 }
 
@@ -1110,8 +1112,8 @@ static void toolbar_trash_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
-	g_return_if_fail(toolbar_item->parent);
+	cm_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item->parent);
 	
 	switch (toolbar_item->type) {
 	case TOOLBAR_MSGVIEW:
@@ -1135,8 +1137,8 @@ static void toolbar_delete_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
-	g_return_if_fail(toolbar_item->parent);
+	cm_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item->parent);
 	
 	switch (toolbar_item->type) {
 	case TOOLBAR_MSGVIEW:
@@ -1162,7 +1164,7 @@ static void toolbar_compose_cb(GtkWidget *widget, gpointer data)
 	MainWindow *mainwin;
 	MessageView *msgview;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1188,7 +1190,7 @@ static void toolbar_learn(gpointer data, guint as_spam)
 	MainWindow *mainwin;
 	MessageView *msgview;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1216,7 +1218,7 @@ static void toolbar_learn_cb(GtkWidget *widget, gpointer data)
 	MainWindow *mainwin;
 	MessageView *msgview;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1244,8 +1246,8 @@ static void toolbar_learn_cb(GtkWidget *widget, gpointer data)
  */
 static void toolbar_reply_cb(GtkWidget *widget, gpointer data)
 {
-	toolbar_reply(data, prefs_common.reply_with_quote ? 
-		      COMPOSE_REPLY_WITH_QUOTE : COMPOSE_REPLY_WITHOUT_QUOTE);
+	toolbar_reply(data, (prefs_common.reply_with_quote ? 
+		      COMPOSE_REPLY_WITH_QUOTE : COMPOSE_REPLY_WITHOUT_QUOTE));
 }
 
 
@@ -1255,8 +1257,8 @@ static void toolbar_reply_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_all_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data,
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_ALL_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_ALL_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE));
 }
 
 
@@ -1266,8 +1268,8 @@ static void toolbar_reply_to_all_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_list_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data, 
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_LIST_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_LIST_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE));
 }
 
 
@@ -1277,8 +1279,8 @@ static void toolbar_reply_to_list_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_sender_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data, 
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_SENDER_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_SENDER_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE));
 }
 
 /*
@@ -1289,7 +1291,7 @@ static void toolbar_addrbook_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	Compose *compose;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1311,7 +1313,7 @@ static void toolbar_addrbook_cb(GtkWidget *widget, gpointer data)
  */
 static void toolbar_forward_cb(GtkWidget *widget, gpointer data)
 {
-	toolbar_reply(data, COMPOSE_FORWARD);
+	toolbar_reply(data, (COMPOSE_FORWARD));
 }
 
 /*
@@ -1323,7 +1325,7 @@ static void toolbar_prev_unread_cb(GtkWidget *widget, gpointer data)
 	MainWindow *mainwin;
 	MessageView *msgview;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1345,7 +1347,7 @@ static void toolbar_prev_unread_cb(GtkWidget *widget, gpointer data)
 		
 		/* Now we need to update the messageview window */
 		if (msgview->mainwin->summaryview->selected) {
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			MsgInfo * msginfo = summary_get_selected_msg(msgview->mainwin->summaryview);
 		       
 			if (msginfo)
@@ -1370,7 +1372,7 @@ static void toolbar_next_unread_cb(GtkWidget *widget, gpointer data)
 	MainWindow *mainwin;
 	MessageView *msgview;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1392,7 +1394,7 @@ static void toolbar_next_unread_cb(GtkWidget *widget, gpointer data)
 
 		/* Now we need to update the messageview window */
 		if (msgview->mainwin->summaryview->selected) {
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			MsgInfo * msginfo = summary_get_selected_msg(msgview->mainwin->summaryview);
 			
 			if (msginfo)
@@ -1413,7 +1415,7 @@ static void toolbar_ignore_thread_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1435,7 +1437,7 @@ static void toolbar_watch_thread_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1456,7 +1458,7 @@ static void toolbar_cancel_inc_cb(GtkWidget *widget, gpointer data)
 {
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 	inc_cancel_all();
 	imap_cancel_all();
 }
@@ -1467,7 +1469,7 @@ static void toolbar_print_cb(GtkWidget *widget, gpointer data)
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1506,7 +1508,7 @@ static void toolbar_close_cb(GtkWidget *widget, gpointer data)
 	MessageView *messageview;
 	Compose *compose;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1524,12 +1526,17 @@ static void toolbar_close_cb(GtkWidget *widget, gpointer data)
 	}
 }
 
+static void toolbar_preferences_cb(GtkWidget *widget, gpointer data)
+{
+	prefs_gtk_open();
+}
+
 static void toolbar_open_mail_cb(GtkWidget *widget, gpointer data)
 {
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
 	MainWindow *mainwin;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1575,7 +1582,7 @@ static void toolbar_linewrap_all_cb(GtkWidget *widget, gpointer data)
 	compose_toolbar_cb(A_LINEWRAP_ALL, data);
 }
 
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 static void toolbar_check_spelling_cb(GtkWidget *widget, gpointer data)
 {
 	compose_toolbar_cb(A_CHECK_SPELLING, data);
@@ -1593,7 +1600,7 @@ static void toolbar_actions_execute_cb(GtkWidget *widget, gpointer data)
 	MessageView *msgview;
 	gpointer parent = toolbar_item->parent;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1621,7 +1628,7 @@ static MainWindow *get_mainwin(gpointer data)
 	MainWindow *mainwin = NULL;
 	MessageView *msgview;
 
-	g_return_val_if_fail(toolbar_item != NULL, NULL);
+	cm_return_val_if_fail(toolbar_item != NULL, NULL);
 
 	switch(toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -1697,6 +1704,7 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 		{ A_DRAFT,		toolbar_draft_cb      		},
 		{ A_OPEN_MAIL,		toolbar_open_mail_cb		},
 		{ A_CLOSE,		toolbar_close_cb		},
+		{ A_PREFERENCES,	toolbar_preferences_cb		},
 		{ A_INSERT,		toolbar_insert_cb     		},
 		{ A_ATTACH,		toolbar_attach_cb     		},
 		{ A_SIG,		toolbar_sig_cb	      		},
@@ -1704,7 +1712,7 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 		{ A_LINEWRAP_CURRENT,	toolbar_linewrap_current_cb   	},
 		{ A_LINEWRAP_ALL,	toolbar_linewrap_all_cb   	},
 		{ A_ADDRBOOK,		toolbar_addrbook_cb		},
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 		{ A_CHECK_SPELLING,     toolbar_check_spelling_cb       },
 #endif
 		{ A_CLAWS_ACTIONS,	toolbar_actions_execute_cb	},
@@ -1720,15 +1728,15 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 		}
 	}
 }
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 #define TOOLBAR_ITEM(item,icon,text,tooltip) {								\
 	item = GTK_WIDGET(gtk_tool_button_new(icon, text));						\
 	gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(item), FALSE);					\
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(item), TRUE);					\
 	g_signal_connect (G_OBJECT(item), "clicked", G_CALLBACK(toolbar_buttons_cb), toolbar_item);	\
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(item), -1);				\
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(item), GTK_TOOLTIPS(toolbar_tips),			\
-			tooltip, NULL);									\
+	CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(item), 							\
+			tooltip);									\
 }
 
 #define TOOLBAR_MENUITEM(item,icon,text,tooltip,menutip) {						\
@@ -1739,10 +1747,9 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(item), TRUE);					\
 	g_signal_connect (G_OBJECT(item), "clicked", G_CALLBACK(toolbar_buttons_cb), toolbar_item);	\
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(item), -1);				\
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(item), GTK_TOOLTIPS(toolbar_tips),			\
-			tooltip, NULL);									\
-	gtk_menu_tool_button_set_arrow_tooltip(GTK_MENU_TOOL_BUTTON(item), 				\
-				GTK_TOOLTIPS(toolbar_tips), menutip, NULL);				\
+	CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(item), 							\
+			tooltip);									\
+	CLAWS_SET_ARROW_TIP(GTK_MENU_TOOL_BUTTON(item), menutip);					\
 	child = gtk_bin_get_child(GTK_BIN(item)); 							\
 	gchild = gtk_container_get_children(								\
 			GTK_CONTAINER(child)); 								\
@@ -1782,11 +1789,30 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 }
 #endif
 
-#define MAKE_MENU(entries,path,btn) {									\
-	n_menu_entries = sizeof(entries) /								\
-		sizeof(entries[0]);									\
-	menu = menu_create_items(entries, n_menu_entries, path, &factory, toolbar_item);		\
-	gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(btn), menu);					\
+#define ADD_MENU_ITEM(name,cb,data) {							\
+	item = gtk_menu_item_new_with_mnemonic(name);					\
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);				\
+	g_signal_connect(G_OBJECT(item), "activate",					\
+			 G_CALLBACK(cb),						\
+			   toolbar_item);						\
+	g_object_set_data(G_OBJECT(item), "int-value", GINT_TO_POINTER(data));		\
+	gtk_widget_show(item);								\
+}
+
+static void toolbar_reply_menu_cb(GtkWidget *widget, gpointer data)
+{
+	gpointer int_value = g_object_get_data(G_OBJECT(widget), "int-value");
+	ToolbarItem *toolbar_item = (ToolbarItem *)data;
+	
+	toolbar_reply(toolbar_item, GPOINTER_TO_INT(int_value));
+}
+
+static void toolbar_learn_menu_cb(GtkWidget *widget, gpointer data)
+{
+	gpointer int_value = g_object_get_data(G_OBJECT(widget), "int-value");
+	ToolbarItem *toolbar_item = (ToolbarItem *)data;
+	
+	toolbar_learn(toolbar_item, GPOINTER_TO_INT(int_value));
 }
 
 /**
@@ -1805,17 +1831,15 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 	GtkWidget *icon_news;
 	GtkWidget *icon_ham;
 	GtkWidget *item;
-	GtkWidget *menu;
-	guint n_menu_entries;
-	GtkItemFactory *factory;
 	ToolbarClawsActions *action_item;
 	GSList *cur;
 	GSList *toolbar_list;
 	Toolbar *toolbar_data;
-#ifndef MAEMO
-	GtkTooltips *toolbar_tips;
-	
- 	toolbar_tips = gtk_tooltips_new();
+	GtkWidget *menu;
+#ifndef GENERIC_UMPC
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = gtk_tooltips_new();
+#endif
 #endif	
 	toolbar_read_config_file(type);
 	toolbar_list = toolbar_get_list(type);
@@ -1872,12 +1896,16 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Close window"));
 			toolbar_data->close_window_btn = item; 
 			break;
+		case A_PREFERENCES:
+			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Open preferences"));
+			toolbar_data->preferences_btn = item; 
+			break;
 		case A_OPEN_MAIL:
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Open email"));
 			toolbar_data->open_mail_btn = item; 
 			break;
 		case A_COMPOSE_EMAIL:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Compose Email"),
 				_("Compose with selected Account"));
@@ -1910,16 +1938,22 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			toolbar_data->learn_ham_icon = icon_ham; 
 			g_object_ref(toolbar_data->learn_ham_icon);
 
-			MAKE_MENU(learn_entries,"<LearnSpam>",toolbar_data->learn_spam_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("Learn as _Spam"), toolbar_learn_menu_cb, TRUE);
+			ADD_MENU_ITEM(_("Learn as _Ham"), toolbar_learn_menu_cb, FALSE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->learn_spam_btn), menu);
 			break;
 		case A_REPLY_MESSAGE:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Message"),
 				_("Reply to Message options"));
 			toolbar_data->reply_btn = item;
 
-			MAKE_MENU(reply_entries,"<Reply>",toolbar_data->reply_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->reply_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Message"));
@@ -1927,13 +1961,16 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 #endif
 			break;
 		case A_REPLY_SENDER:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Sender"),
 				_("Reply to Sender options"));
 			toolbar_data->replysender_btn = item;
 
-			MAKE_MENU(replysender_entries,"<ReplySender>",toolbar_data->replysender_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_SENDER_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replysender_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Sender"));
@@ -1941,13 +1978,16 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 #endif
 			break;
 		case A_REPLY_ALL:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to All"),
 				_("Reply to All options"));
 			toolbar_data->replyall_btn = item;
 
-			MAKE_MENU(replyall_entries,"<ReplyAll>",toolbar_data->replyall_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_ALL_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replyall_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to All"));
@@ -1955,13 +1995,16 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 #endif
 			break;
 		case A_REPLY_ML:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Mailing-list"),
 				_("Reply to Mailing-list options"));
 			toolbar_data->replylist_btn = item;
 
-			MAKE_MENU(replylist_entries,"<ReplyList>",toolbar_data->replylist_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_LIST_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replylist_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Mailing-list"));
@@ -1969,13 +2012,17 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 #endif
 			break;
 		case A_FORWARD:
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
 				_("Forward Message"),
 				_("Forward Message options"));
 			toolbar_data->fwd_btn = item;
 
-			MAKE_MENU(forward_entries,"<Forward>",toolbar_data->fwd_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Forward"), toolbar_reply_menu_cb, COMPOSE_FORWARD_INLINE);
+			ADD_MENU_ITEM(_("For_ward as attachment"), toolbar_reply_menu_cb, COMPOSE_FORWARD_AS_ATTACH);
+			ADD_MENU_ITEM(_("Redirec_t"), toolbar_reply_menu_cb, COMPOSE_REDIRECT);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->fwd_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Forward Message"));
@@ -2044,7 +2091,7 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Address book"));
 			toolbar_data->addrbook_btn = item;
 			break;
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 		case A_CHECK_SPELLING:
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Check spelling"));
 			toolbar_data->spellcheck_btn = item;
@@ -2074,13 +2121,15 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 
 	}
 	toolbar_data->toolbar = toolbar;
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
+#if !(GTK_CHECK_VERSION(2,12,0))
 	toolbar_data->tooltips = toolbar_tips;
+#endif
 #endif
 	gtk_widget_show_all(toolbar);
 
 	if (type == TOOLBAR_MAIN) {
-#ifdef MAEMO
+#ifdef GENERIC_UMPC
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 		GtkWidget *progressbar = gtk_progress_bar_new();
 		item = GTK_WIDGET(gtk_tool_item_new());
@@ -2131,7 +2180,7 @@ void toolbar_update(ToolbarType type, gpointer data)
 	Compose    *compose = (Compose*)data;
 	MessageView *msgview = (MessageView*)data;
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	switch(type) {
 	case TOOLBAR_MAIN:
 		toolbar_data = mainwin->toolbar;
@@ -2171,9 +2220,9 @@ void toolbar_update(ToolbarType type, gpointer data)
 	default:
 		return;
 	}
-
+#ifdef MAEMO
 	hildon_window_remove_toolbar(HILDON_WINDOW(handlebox), GTK_TOOLBAR(toolbar_data->toolbar));
-
+#endif
 	toolbar_init(toolbar_data);
  	toolbar_data = toolbar_create(type, handlebox, data);
 #endif
@@ -2198,6 +2247,8 @@ void toolbar_update(ToolbarType type, gpointer data)
 	}
 }
 
+#if !GTK_CHECK_VERSION(2,14,0)
+/* Work around http://bugzilla.gnome.org/show_bug.cgi?id=56070 */
 #define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {		\
 	gboolean in_btn1 = FALSE, in_btn2 = FALSE;		\
 	if (GTK_IS_BUTTON(widget))				\
@@ -2246,6 +2297,11 @@ void toolbar_update(ToolbarType type, gpointer data)
 			GTK_BUTTON(child)->in_button = in_btn1;	\
 	}							\
 }
+#else
+#define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {		\
+	gtk_widget_set_sensitive(widget, sensitive);		\
+}
+#endif
 
 void toolbar_main_set_sensitive(gpointer data)
 {
@@ -2325,7 +2381,7 @@ void toolbar_main_set_sensitive(gpointer data)
 	
 	if (toolbar->trash_btn)
 		SET_WIDGET_COND(toolbar->trash_btn,
-			M_TARGET_EXIST|M_ALLOW_DELETE);
+			M_TARGET_EXIST|M_ALLOW_DELETE|M_NOT_NEWS);
 
 	if (toolbar->delete_btn)
 		SET_WIDGET_COND(toolbar->delete_btn,
@@ -2402,7 +2458,7 @@ void toolbar_comp_set_sensitive(gpointer data, gboolean sensitive)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->linewrap_all_btn, sensitive);
 	if (compose->toolbar->addrbook_btn)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->addrbook_btn, sensitive);
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	if (compose->toolbar->spellcheck_btn)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->spellcheck_btn, sensitive);
 #endif
@@ -2448,7 +2504,7 @@ static void toolbar_init(Toolbar * toolbar)
 	toolbar->linewrap_current_btn	= NULL;	
 	toolbar->linewrap_all_btn     	= NULL;	
 	toolbar->addrbook_btn     	= NULL;	
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	toolbar->spellcheck_btn   	= NULL;
 #endif
 
@@ -2464,7 +2520,7 @@ static void toolbar_reply(gpointer data, guint action)
 	MessageView *msgview;
 	GSList *msginfo_list = NULL;
 
-	g_return_if_fail(toolbar_item != NULL);
+	cm_return_if_fail(toolbar_item != NULL);
 
 	switch (toolbar_item->type) {
 	case TOOLBAR_MAIN:
@@ -2474,15 +2530,15 @@ static void toolbar_reply(gpointer data, guint action)
 		break;
 	case TOOLBAR_MSGVIEW:
 		msgview = (MessageView*)toolbar_item->parent;
-		g_return_if_fail(msgview != NULL);	
+		cm_return_if_fail(msgview != NULL);	
 		msginfo_list = g_slist_append(msginfo_list, msgview->msginfo);
 		break;
 	default:
 		return;
 	}
 
-	g_return_if_fail(msgview != NULL);
-	g_return_if_fail(msginfo_list != NULL);
+	cm_return_if_fail(msgview != NULL);
+	cm_return_if_fail(msginfo_list != NULL);
 	compose_reply_from_messageview(msgview, msginfo_list, action);
 	g_slist_free(msginfo_list);
 
